* PREPARE-PIA
* (*.do files should work with /k32000 memory except when marked)
* (an asterisk below a *.do file indicates that the program needs to be executed after changes to economic variables on earlier levels)

* Order of Commands to Run for PIA at FIRM LEVEL:
* -----------------------------------------------

cd "c:/data/"
global dp = "c:/data/brazprod/%stata/%1prepare-pia"
set more off
clear
set mem 80m

capture mkdir "brazprod/data"
capture mkdir "brazprod/data/pia-e"
capture mkdir "brazprod/data/life"
capture mkdir "brazprod/data/logs"

* do $dp/prep-filters.do
                    /* Creates variables for birth year and for translations between standards */
                    /* Entering data: "brazprod/filters/cnae-niv100-piatex.txt" (original in accordance with pia.pdf), 
                                      "brazprod/filters/cnae-niv100-orig.csv" (original "NVEL 100 x CNAE citando N100 PIM-PF.rtf" transformed to "cnae-niv100-raw.csv")
                                      "brazprod/filters/tradprod.csv" (originally tradprod.xls), 
                                      "brazprod/cgc-list/cgc-nasc.csv" (originally M001.sd2),
                                      "brazprod/cgc-list/pia`yr'-nasc.csv" (96-98) (originally Cad1.sd2, Cad2.sd2, Cad3.sd2) */
                    /* Output: "brazprod/filters/niv10080.dta",
                               "brazprod/cgc-list/cgc-nasc.dta",
                               "brazprod/filters/cnae-niv100",
                               "brazprod/filters/cnae-niv100-piatex.csv", [Note: "brazprod/filters/cnae-niv100-old.csv" previous (incomplete) file]
                               "brazprod/filters/cnae-niv100.csv" */

* do $dp/read-emp86-90.do
*                   /* Creates dataset at firm level for all variables */
                    /* Entering data: "brazprod/pia-e/piae`yr'.csv" (originally piae`yr'.sd2) */
                    /* Output: "brazprod/data/pia-e/piae`yr'.dta" (86-90) */
* do $dp/read-emp92-95.do
*                   /* Creates dataset at firm level for all variables */
                    /* Entering data: "brazprod/pia-e/piae`yr'.csv" (originally piae`yr'.sd2), 
                                      "brazprod/cgc-lig/cgclig`yr'.csv" (92-95) (originally cgc-lig`yr'.sd2) */
                    /* Output: "brazprod/data/pia-e/piae`yr'.dta" (92-95) */
* do $dp/read-emp96-98.do
*                   /* Creates dataset at firm level for all variables */
                    /* Entering data: "brazprod/pia-e/pianova`yr'.csv" (originally pianova`yr'.zip) 
                                      "brazprod/filters/cnae-niv100.csv" (from prep-filters.do) */
                    /* Output: "brazprod/data/pia-e/piae`yr'.dta" (86-90)
                               "brazprod/cgc-list/cgc-cnae-96-98" */
* do $dp/read-emp86-95-correct.do
*                   /* Corrects reading error in PIA 94 */
                    /* Entering data: "brazprod/pia-e/piae94.dta" (created by read-emp92-95.do) */
                    /* Output: "brazprod/data/pia-e/piae94.dta" (corrected) */


* do $dp/cgc-lig.do   /* Creates CGC connection files and updates datafiles */
                    /* Entering data: "brazprod/cgc-lig/cgclig`yr'.csv" (86-95) (originally cgc-lig`yr'.sd2)
                                      "brazprod/cgc-lig/cgccor`yr'.csv" (86-90) (originally cgccor`yr'.sd2)
                                      "brazprod/pia-e/pianova`yr'.csv" (96-98)
                                      "brazprod/cgc-list/cgc-nasc.dta" (from prep-filters.do) */
                    /* Output: "brazprod/cgc-lig/cgc-lig.dta" */



* Careful: Set max size to /k64000
* do $dp/merge-emp.do    
*               /* Creates master dataset for all years, including both firm and plant level data */
                /* Entering data: "brazprod/data/pia-e/piae`yr'.dta" (86-95), 
                                  "brazprod/filters/niv10080.dta" (from prep-filters),
                                  "brazprod/cgc-list/cgc-nasc.dta" (from prep-filters)
                                  "brazprod/cgc-lig/cgc-lig.dta" (from cgc-lig) */
                /* OUTPUT: "brazprod/data/pia-emp.dta" */


* Careful: Set max size to /k64000
* do $dp/group-life-emp.do   
                    /* Traces cgc's in sample over time and groups them into four files */
                    /* Entering data: "brazprod/data/pia-emp.dta" (merge-emp-yrs) */
                    /* Output: "brazprod/data/life/firms0-all.dta",
                               "brazprod/data/life/firms1-cont.dta",
                               "brazprod/data/life/firms2-cont-ext.dta",
                               "brazprod/data/life/firms3-cont-late.dta"
                               "brazprod/data/life/firms4-suspend.dta" */ 
* Careful: Set max size to /k64000
* do $dp/analyz-entry-emp.do
                    /* Categorizes firms by type of entry into sample */
                    /* Entering data: "brazprod/data/life/firms0-all.dta" (analyz-life-emp),
                                      "brazprod/data/pia-emp.dta" (merge-emp-yrs) */
                    /* Output: "brazprod/data/life/firms-entry.dta" */
* do $dp/analyz-exit-emp.do
                    /* Categorizes firms by type of exit from sample, including divestitures, mergers, times of suspension and closing */
                    /* Entering data: "brazprod/data/life/firms`n'-all.dta" (`n': 0-4) (analyz-life-emp),
                                      "brazprod/data/life/firms-entry.dta" (analyz-entry) */
                    /* Output: "brazprod/data/life/firms-exit.dta" */
* Careful: Set max size to /k64000
* do $dp/analyz-life-emp.do
*                   /* Analyzes/Corrects (!) types of CGC changes and exit behavior and corrects "brazprod/data/pia-emp.dta" accordingly */
                    /* Entering data: "brazprod/data/pia-emp.dta" (merge-emp-yrs)
                                      "brazprod/data/life/firms-entry.dta" (analyz-entry-emp) */
                    /* OUTPUT: "brazprod/data/pia-finl.dta" */
* Careful: Set max size to /k64000
* do $dp/analyz-refer-emp.do 
*                   /* Analyzes/Corrects (!) types of CGC changes and exit behavior and corrects "brazprod/data/pia-emp.dta" accordingly */
                    /* Entering data: "brazprod/data/pia-finl.dta" (analyz-life-yrs)
                                      "brazprod/cgc-lig/recat.csv" (manual list of recategorizations) */
                    /* OUTPUT: "brazprod/cgc-lig/refer.dta",
                               "brazprod/cgc-lig/firmhead.dta",
                               "brazprod/data/pia-finl.dta" */
                    /* Note: When re-running analyz-refer-emp.do, previous changes to pia-finl.dta are undone */


* do $dp/ratios.do    /* Creates dataset at firm level for ratios of select variables */
                    /* Entering data: "brazprod/pia-e/piae`yr'.csv" (originally piae`yr'.sd2)
                                      "brazprod/pia-e/pianova`yr'.csv" (originally pianova`yr'.zip) */
                    /* Output: "brazprod/data/pia-ratios.dta" */

* Careful: Set max size to /k64000
* do $dp/cgc-list.do
                    /* Creates list of all CGCs that were present or related once between 86 and 98 */  
                    /* Entering data: "brazprod/data/pia-finl.dta"
                                      "brazprod/cgc-lig/refer.dta" */                 
                    /* OUTPUT: "brazprod/cgc-list/cgc-list.dta"
                               "A:/cgc-list.csv" */

* do $dp/plot-categs.do
                    /* Plots categories to logfile */
                    /* Entering data: "brazprod/cgc-lig/firmhead.dta" (analyz-refer-emp.do) */
                    /* Output: Log-File "brazprod/data/logs/categs.log" */
