version 6.0
tempfile piae96 piae97 piae98 piae
tempfile indtype realex expimp
tempfile imp89 imp90 imp92 imp93 imp94 imp95 imp96 imp97 imp98
tempfile exp89 exp90 exp92 exp93 exp94 exp95 exp96 exp97 exp98 expall
tempfile realx88 realx89 realx90 realx91 realx92 realx93 realx94 realx95 realx96 realx97 realx98

/* Load Industry Definitions */
/*---------------------------*/
use "brazprod\deflate\comp-defl.dta", clear
keep niv80map indtype
sort niv80map
preserve
    use "brazprod\filters\niv10080.dta", clear
    rename nivmap niv80map
    sort niv80map
    save `indtype', replace
restore
merge niv80map using `indtype', nokeep   /* Agriculture drops out */
label var niv80 "Sector of Industry (NIV80)"
drop niv100 niv80map _merge
sort niv80
quietly by niv80: keep if _n==1
order niv80
replace indtype="bi" if niv80==3201  /* Other Industries are considered Intermediate Goods */
save `indtype', replace

/* Read-in Export Files */
/*----------------------*/
local yr 89
while `yr' <=98 {
if `yr'==91 {local yr 92}
insheet using "brazprod\exp-imp\exp`yr'.csv", clear
rename cgc firm
label var firm "Tax Number (CGC)"
replace p80="3201" if substr(p80,1,1)=="X" /* Entry starts with X */
gen int niv80=int(real(p80))
label var niv80 "Sector of Industry (NIV80)"
drop nbmsh p80
egen exp=sum(fob), by(firm)
sort firm
quietly by firm: keep if _n==1
label var exp "Exports (US$ fob)"
drop fob niv80
gen byte year=`yr'
label var year "Calendar Year"
order firm year exp
sort firm year
save `exp`yr'', replace
local yr=`yr'+1
}
/* Append to one dataset */
use `exp89', clear
append using `exp90'
append using `exp92'
append using `exp93'
append using `exp94'
append using `exp95'
append using `exp96'
append using `exp97'
append using `exp98'
sort firm year
save `expall', replace

/* Read-in Import Files */
/*----------------------*/
local yr 89
while `yr' <=98 {
if `yr'==91 {local yr 92}
if `yr'==93 {local yr 97}
insheet using "brazprod\exp-imp\imp`yr'.csv", clear
drop nbmsh
rename cgc firm
label var firm "Tax Number (CGC)"
replace p80="3201" if substr(p80,1,1)=="X" /* Entry starts with X */
gen int niv80=int(real(p80))
label var niv80 "Sector of Industry (NIV80)"
label var fob "Import Value US$ FOB"
drop p80
sort niv80
merge niv80 using `indtype', nokeep
replace indtype="agrc" if int(niv80/100)==1
replace indtype="unkn" if _merge==1 & indtype~="agrc"
drop _merge
gen _capgood=1 if substr(indtype,1,2)=="bk"
egen impintm=sum(fob), by(firm _capgood)  /* Grouping into Non-capital and capital goods */
gen  impcap=impintm if _capgood==1
replace impintm=. if _capgood==1
sort firm _capgood
quietly by firm _capgood: keep if _n==1
drop fob niv80 indtype _capgood
replace impintm=0 if impintm==.
replace impcap=0 if impcap==.
egen _impintm=sum(impintm), by(firm)
egen _impcap=sum(impcap), by(firm)
drop impintm impcap
rename _impcap impcap
rename _impintm impintm
sort firm
quietly by firm: keep if _n==1
label var impcap "Imports Capital Goods (US$ fob)"
label var impintm "Imports Interm. Goods (US$ fob)"
gen byte year=`yr'
label var year "Calendar Year"
order firm year impintm impcap
sort firm year
save `imp`yr'', replace
local yr=`yr'+1
}

/* Create joint dataset */
/*----------------------*/
use `expall', clear
gen byte indnoimp=.
gen byte indnoexp=.
format indnoimp indnoexp %1.0f
label var indnoimp "Exporter without Imports"
label var indnoexp "Importer without Exports"
local yr 89
while `yr'<=98 {
if `yr'==91 {local yr 92}
if `yr'==93 {local yr 97}
sort firm year
merge firm year using `imp`yr''
replace indnoimp=1 if _merge==1 & year==`yr'
replace indnoexp=1 if _merge==2 & year==`yr'
drop _merge
local yr=`yr'+1
}
order firm year exp impintm impcap indnoimp indnoexp
sort firm year
label var exp "Exports (fob)"
label var impintm "Imports Interm. Goods (fob)"
label var impintm "Imports Capital Goods (fob)"
save `expimp', replace

/* Prepare Temp. Real Exchange Rate Files */
use "brazprod\deflate\realexch", clear
drop if defltype~="realexch"
drop defltype
gen byte _marker=1
sort _marker
local yr 89
preserve
while `yr'<=98 {
    restore, preserve
    keep _marker jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    save `realx`yr'', replace
    local yr=`yr'+1
}
restore

/* Create nominal series, then deflate using real exchange rate */
/*--------------------------------------------------------------*/
/* Create pseudo-year values (assumption: equal likelihood to export/import in all months) */
capture program drop deflexc
program define deflexc
    args varname yr
    replace `varname'=`varname'*(1/12)*(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr'+sep`yr'+oct`yr'+nov`yr'+dec`yr')
end

use `expimp', clear
gen byte _marker=1
local yr 89
while `yr'<=98 {
    if `yr'==91 {local yr 92}
    sort _marker
    merge _marker using `realx`yr''
    drop _merge
    deflexc exp `yr'
    deflexc impintm `yr'
    deflexc impcap `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    local yr=`yr'+1
    }
drop _marker
sort firm year

gen byte indexp=1 if exp>0 & exp~=.
gen byte indimp=1 if (impcap+impintm)>0 & impcap~=. & impintm~=.
format indimp indexp %1.0f
label var indexp "Exporter"
label var indimp "Importer"
order firm year exp impintm impcap indexp indnoimp indimp indnoexp
preserve

/* Include import and export share information after 1996 */
/*--------------------------------------------------------*/
local yr 96     /* Do not use values other than 96, 97, 98 */
while `yr'<=98 {
insheet using "brazprod\pia-e\pianova`yr'.csv", clear
drop if modelo=="S"  /* Drop simplified ("S") questionnaires */
drop firm indsuc indpred
rename empresa firm
label var firm "Tax Number (CGC)"
format firm %8.0f
gen byte year=`yr'
label var year "Calendar Year"
format year %2.0f
rename mercint pcsldom
label var pcsldom "Sales: Perc. Domestic"
rename mercosul pcslmsul
label var pcslmsul "Sales: Perc. Mercosul"
rename outrosp pcslexp
label var pcslexp "Sales: Perc. Other Exports"
rename percnac pcinpdom
label var pcinpdom "Interm. Goods: Perc. Domestic"
rename percest pcinpfor
label var pcinpfor "Interm. Goods: Perc. Foreign"
keep firm year pcsldom pcslmsul pcslexp pcinpdom pcinpfor
sort firm year
save `piae`yr'', replace
local yr=`yr'+1
}

/* FINALIZE */
/*----------*/
restore
merge firm year using `piae96'
drop _merge
sort firm year
merge firm year using `piae97'
drop _merge
sort firm year
merge firm year using `piae98'
drop _merge
sort firm year
save "brazprod\exp-imp\exp-imp", replace
