/* optional: use "brazprod/filters/sectors.dta" (from prep-intl-series.do), if prep-intl-series.do was executed once before */

version 7
set matsize 180
tempfile brazprod sicniv sic2dsel series indcode 
tempfile MetalMining Lumber Furniture Paper Printing Chemicals Petroleum Rubber Leather Stone PrimaryMetal FabricatedMetal Machinery ElectricalMachinery TransportationEquipment MeasuringInstruments Miscellaneous BituminousAndLignite OilAndGas NonMetallicMining Food Tobacco Textile Apparel

/* Niv100 - SIC filter */
/*---------------------*/

use "brazcomp/filters/sic2niv-loose", clear
keep sic niv
gen byte _sic2d = int(sic/100)
sort niv
by niv: egen sic2d = mode(_sic2d)
replace sic2d = 35 if sic2d==. & niv==1310
drop _sic2d sic
order sic2d
rename niv niv100
sort niv100
by niv100: keep if _n==1
sort niv100
expand 3 if niv100==22
expand 2 if niv100==210
expand 2 if niv100==1710
sort niv100
by niv100: replace niv100 = 2210 if niv100==  22 & _n==1
sort niv100
by niv100: replace niv100 = 2220 if niv100==  22 & _n==1
sort niv100
by niv100: replace niv100 = 2230 if niv100==  22 & _n==1
sort niv100
by niv100: replace niv100 =  220 if niv100== 210 & _n==1
replace sic2d = 14 if niv100 == 220
sort niv100
by niv100: replace niv100 = 1720 if niv100==1710 & _n==1
sort niv100
* preserve
*   use "brazcomp/filters/sectors", clear
*   keep niv100 desc100
*   sort niv100
*   save `brazprod'
* restore
* joinby niv100 using `brazprod', unmatched(both) _merge(_merge)
* sort niv100
* by niv100: keep if _n==1
* drop if _merge==1
preserve
*   drop _merge desc100
  sort sic2d
  compress
  save `sicniv'
restore
keep sic2d
sort sic2d
by sic2d: keep if _n==1
save `sic2dsel'

/* Select Series */
/*---------------*/

insheet using "brazprod/addl/ivs/ppi-us/pc.series", clear
foreach var in begin_year begin_period end_year end_period v10 {
  rename `var' _`var'
  }
local prevvar = ""
foreach var in begin_year begin_period end_year end_period v10 {
  if "`prevvar'"~="" { rename _`var' `prevvar' }
  local prevvar = "`var'"
  }
rename _ indic
keep if substr(industry,-2,2)=="__"
gen sic2d = int(real(subinstr(industry,"_","",.)))
compress
order sic2d industry
sort sic2d
merge sic2d using `sic2dsel'
count if _merge==2
if `r(N)' > 0 { 
    tab _merge
    STOP 
    }
drop if _m==1
drop _m
preserve
  insheet using "brazprod/addl/ivs/ppi-us/pc.industry", clear
  rename v1 industry_code
  rename v2 industry_name
  drop in 1
  keep if substr(industry_code,-2,2)=="__"
  sort industry_code
  save `indcode'
restore
sort industry_code
merge industry_code using `indcode', nokeep
drop _m
compress
keep sic2d series industry_name
order series
sort series 
label var series_id "BLS Series ID"
label var sic2d     "SIC 2-digit concordance"
label var industry_name "Sector description"
compress
save "brazprod/filters/us-sectors", replace
keep series sic2d 
sort series_id 
save `series'

/* Read-in Individual Series */
/*--------------------------*/

foreach ser in 1.MetalMining 10.Lumber 11.Furniture 12.Paper 13.Printing 14.Chemicals 15.Petroleum 16.Rubber 17.Leather 18.Stone 19.PrimaryMetal 20.FabricatedMetal 21.Machinery 22.ElectricalMachinery 23.TransportationEquipment 24.MeasuringInstruments 25.Miscellaneous 3.BituminousAndLignite 4.OilAndGas 5.NonMetallicMining 6.Food 7.Tobacco 8.Textile 9.Apparel {
  di
  disp in green "Reading " in yellow "`ser'"
  di
  di
  insheet using "brazprod/addl/ivs/ppi-us/pc.data.`ser'", clear
  drop footnotes
  rename value ppi
  rename period month
  compress
  sort series_id
  joinby series_id using `series', unmatched(both) _merge(_merge)
  keep if _m==3
  count
  if `r(N)' > 0 {
    drop _m series_id
    replace ppi=ppi/100
    order sic2d
    sort sic2d year month
    drop if year<1986
    collapse (mean) ppi, by(sic2d year month)
    label var sic2d "SIC 2-digit concordance"
    label var year  "Calendar Year"
    label var month "Month" 
    label var ppi   "BLS PPI" 
    sort sic2d year month
    compress
    local filename = substr("`ser'",index("`ser'",".")+1,.)
    save ``filename''
    }
  }

local i 1
foreach ser in 1.MetalMining 10.Lumber 11.Furniture 12.Paper 13.Printing 14.Chemicals 15.Petroleum 16.Rubber 17.Leather 18.Stone 19.PrimaryMetal 20.FabricatedMetal 21.Machinery 22.ElectricalMachinery 23.TransportationEquipment 24.MeasuringInstruments 25.Miscellaneous 3.BituminousAndLignite 4.OilAndGas 5.NonMetallicMining 6.Food 7.Tobacco 8.Textile 9.Apparel {
  di
  disp in green "Appending " in yellow "`ser'"
  di
  di
  local filename = substr("`ser'",index("`ser'",".")+1,.)
  capture confirm file ``filename''
  if _rc==0 {
    if `i' == 1 { use ``filename'' }
    else        { append using ``filename'' }
    }  
  local i = `i' + 1
  }

sort sic2d
joinby sic2d using `sicniv', unmatched(both) _merge(_merge)
drop _merge
order niv100 year month ppi sic2d
sort niv100 year month
compress
save "brazprod/addl/ivs/ppi-us/us-ppi", replace
