* DEFLATING
* (In general, try to use *.do with /k64000)

* Order of Deflation Steps:
* -------------------------

cd "c:/data/"
global dp = "c:/data/brazprod/%stata/%3deflate&capstruct-pia"
set more off
clear
set mem 80m

capture mkdir "brazprod/data/deflated"

* do $dp/prep-capcorr.do
                   /* Prepares capital correction factors for later use */
                   /* Entering data: "brazprod/deflate/ibge/otn-ufir-64.csv"
                                     "brazprod/deflate/ibge/inpc-79-mtb-64.csv"
                                     "brazprod/deflate/fgv/igpdi-44.csv"
                                     "brazprod/deflate/fgv/ipadi-69.csv
                                     "brazprod/deflate/fgv/ipaog-69.csv
                                     "brazprod/deflate/contas-nacionais/cap-form-`yr'.csv" (for `yr' in 90 through 98)
                                     "brazprod/deflate/contas-nacionais/cap-form-85.csv" 
                                     "brazprod/deflate/fgv/n100fgv.csv"
                                     "brazprod/filters/niv10080" */
                   /* OUTPUT: "brazprod/deflate/capcorr-inpc.dta"
                              "brazprod/deflate/capcorr-igp-di.dta"
                              "brazprod/deflate/capcorr-di.dta"
                              "brazprod/deflate/capcorr-ipa.dta" */
                              
* do $dp/prep-capstruct86-90.do   
                   /* Prepares capital structure between 1986 and 1990 for later use */
                   /* Entering data: "brazprod/pia-e/piae`yr'.csv" (where `yr'=86,...,90) */
                   /* OUTPUT: "brazprod/data/pia-e/capstruct-86-90" */

* do $dp/deflate-flows-pia-finl.do 
                   /* Deflates All Flows Except Investment */
                   /* Entering data: "brazprod/data/pia-finl.dta"         (from analyz-refer-emp.do) 
                                     "brazprod/deflate/output-defl-`ext'" (from prep-deflators.do; `ext' denotes deflator type)
                                     "brazprod/deflate/input-defl-`ext'"  (from prep-deflators-input.do; `ext' denotes deflator type)
                                     "brazprod/deflate/comp-defl"    (from prep-deflators.do)
                                     "brazprod/deflate/general-defl" (from prep-deflators.do) */
                   /* OUTPUT: "brazprod/data/deflated/pia-flows-`ext'-`moncor'-`saltype'.dta" */

* do $dp/deflate-investment-pia-finl.do 
                   /* Deflates Gross but Not Net Investment Flows */
                   /* Entering data: "brazprod/data/pia-finl.dta"          (from analyz-refer-emp.do) 
                                     "brazprod/deflate/capform-defl-`ext'" (from prep-deflators-capital.do; `ext' denotes deflator type)
                                     "brazprod/deflate/general-defl.dta"   (from prep-deflators.do) */
                   /* OUTPUT: "brazprod/data/deflated/pia-invest-`ext'-`moncor'-`type'.dta" */

* do $dp/defl-capstruct86-90.do 
                   /* Deflates Detailed Capital Stock Figures between 1986 and 1990 */
                   /* Entering data: "brazprod/data/pia-finl.dta"              (from analyz-refer-emp.do) 
                                     "brazprod/data/pia-e/capstruct-86-90.dta" (from prep-capstruct86-90.do)
                                     "brazprod/deflate/ibge/inpc-79-mtb-64.csv"
                                     "brazprod/deflate/fgv/igpdi-44.csv"
                                     "brazprod/deflate/fgv/ipadi-69.csv"
                                     "brazprod/deflate/capform-defl-`ext'"     (from prep-deflators.do; `ext' denotes deflator type)
                                     "brazprod/deflate/general-defl.dta"       (from prep-deflators.do)
                                     "brazprod/deflate/capcorr-`ext'.dta"      (from prep-deflators.do) */
                   /* OUTPUT: "brazprod/data/deflated/pia-cap8690-`ext'-`type'-`corron'.dta" */

* do $dp/deflate-capstock-pia-finl.do 
                   /* Deflates Capital Stock Figures */
                   /* Entering data: "brazprod/data/pia-finl.dta"          (from analyz-refer-emp.do) 
                                     "brazprod/deflate/capform-defl-`ext'" (from prep-deflators-capital.do; `ext' denotes deflator type)
                                     "brazprod/deflate/general-defl.dta"   (from prep-deflators.do)
                                     "brazprod/deflate/capcorr-`ext'.dta"  (from prep-deflators-capital.do) */
                   /* OUTPUT: "brazprod/data/deflated/pia-capstock-`ext'-`type'-`corron'.dta" */

* do $dp/deflate-foracq-pia-finl.do 
                   /* Deflates foreign intermediates and foreign machinery acquisitions */
                   /* Entering data: "brazprod/data/pia-finl.dta"               (from analyz-refer-emp.do) 
                                     "brazprod/deflate/input-defl-forppi.dta"   (from prep-deflators-input.do)
                                     "brazprod/deflate/capform-defl-forppi.dta" (from prep-deflators-capital.do) */
                   /* OUTPUT: "brazprod/data/deflated/pia-foracq-forppi`fdfl'-`moncor'.dta" (`fdfl' in 1 2) */

* do $dp/merge-pia-finl-defl.do
                   /* Creates a joint dataset of all deflated variables, except detailed capital stock */
                   /* Entering data: "brazprod/data/pia-finl.dta"              (from analyz-refer-emp.do) 
                                     "brazprod/data/deflated/pia-invest-`ext'-`moncor'-`type'.dta"
                                     "brazprod/data/deflated/pia-flows-`ext'-`moncor'-`saltype'.dta"
                                     "brazprod/data/deflated/pia-capstock-`ext'-`type'-`corron'.dta"
                                     "brazprod/data/pia-ratios.dta"
                                     "brazprod/data/deflated/pia-foracq-forppi`fdfl'-`moncor'.dta" */
                   /* OUTPUT: "brazprod/data/pia-use-`ext'`fdfl'-`moncor'-`type'-`saltype'-`corron'.dta" */

* do $dp/impute-capstruct-compl.do
                   /* Creates a dataset with detailed capital stock variables */
                   /* Entering data: "brazprod/cgc-lig/refer.dta"              (from analyz-refer-emp.do) 
                                     "brazprod/addl/interest.dta"
                                     "brazprod/data/pia-finl.dta"              (from analyz-refer-emp.do) 
                                     "brazprod/data/pia-use-`ext'`fdfl'-`moncor'-`type'-`saltype'-`corron'.dta" (from merge-pia-finl-defl.do)
                                     "brazprod/data/deflated/pia-cap8690-`ext'-`type'-`corron'.dta"       (from deflate-capstruct86-90.do) */
                   /* OUTPUT: "brazprod/data/pia-capstruct-compl-`ext'`fdfl'-`moncor'-`type'-`saltype'-`corron'"
                              "brazprod/addl/deprec.dta" */
