version 6.0
/*----------------------------------*/
/* Careful: Set max size to /k64000 */
/*----------------------------------*/

tempfile master tmp
tempfile capf86 capf87 capf88 capf89 capf90 capf91 capf92 capf93 capf94 capf95 capf96 capf97 capf98
tempfile inpc86 inpc87 inpc88 inpc89 inpc90 inpc91 inpc92 inpc93 inpc94 inpc95 inpc96 inpc97 inpc98
use "brazprod\data\pia-finl", clear
keep firm year born niv100 niv80map state change chmon chyr acqtot-acqcomp

/* Choose Settings */
/*-----------------*/

local choice 3
/* Choice 1: Mesquita (and general) Deflators 90-98 */
/*        2: PIM-IBGE (and general) Deflators 86-98 */
/*        3: FGV-IPA (and general) Deflators 86-98 */
/*        4: FGV-DI (and general) Deflators 86-98 */
/*        9: Apply INPC to all variables */

local type "ipa-indtot"
/* Type of General Deflator: Used for ground & premises or under choice 9
                              "igp-di", "inpc", "inpc-real", 
                              "ipa-indtot", "ipa-og", "ipa-transf"
        see "brazprod\deflate\general-defl.dta" */

local saltype "ipa-indtot"
/* Type of Wage Deflator: Used for wages and rental rates only (see types above) */

local minyr 86  /* Starting year */
local maxyr 98  /* Ending year */

local moncor 1
/* moncor 1: Month correction within year for flow variables */
/*        0: Do not execute month correction within year for flow variables */


if `choice'==1 {
    local ext "mesq"
    local minyr 90
    }
if `choice'==2 {local ext "pim"}
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {
    local ext "gen"
    local saltype="`type'"
    }


/* The output will be "brazprod\data\deflated\pia-invest-`ext'-`moncor'-`type'" */
/*------------------------------------------------------------------------------*/


/* Transform monetary variables to base "Real" 1995 */
/*--------------------------------------------------*/
capture program drop nominal
program define nominal
  args varname
  replace `varname'=`varname'/2.75 if year==93
  replace `varname'=`varname'/(2.75*1000) if (year==92 | year==90 | year==89)
  replace `varname'=`varname'/(2.75*1000000) if (year==88 | year==87 | year==86)
end
/* Set inadmissible negative values to missing */
capture program drop corrneg
program define corrneg
  args varname
  replace `varname'=. if `varname'<0
end
nominal acqtot
nominal acqbl
nominal acqmasum
nominal acqmadom
nominal acqmause
nominal acqmafor
nominal acqveh
nominal acqother
nominal acqcomp
corrneg acqtot
corrneg acqbl
corrneg acqmasum
corrneg acqmadom
corrneg acqmause
corrneg acqmafor
corrneg acqveh
corrneg acqother
corrneg acqcomp

order firm year state change born chmon chyr acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp niv100 niv80map
sort firm year
save `master', replace


/* Rebase Deflators to Aug 1994 and Create Temp. Deflator Files */
/*--------------------------------------------------------------*/
capture program drop rebase
program define rebase
    args yr
    while `yr'<=98 {
    quietly replace jan`yr'=(jan`yr'/aug94)
    quietly replace feb`yr'=(feb`yr'/aug94)
    quietly replace mar`yr'=(mar`yr'/aug94)
    quietly replace apr`yr'=(apr`yr'/aug94)
    quietly replace may`yr'=(may`yr'/aug94)
    quietly replace jun`yr'=(jun`yr'/aug94)
    quietly replace jul`yr'=(jul`yr'/aug94)
    if `yr'~=94 {quietly replace aug`yr'=(aug`yr'/aug94)}
    quietly replace sep`yr'=(sep`yr'/aug94)
    quietly replace oct`yr'=(oct`yr'/aug94)
    quietly replace nov`yr'=(nov`yr'/aug94)
    quietly replace dec`yr'=(dec`yr'/aug94)
    local yr=`yr'+1
    }
    quietly replace aug94=1
end

if `choice'~=9 {
    use "brazprod\deflate\capform-defl-`ext'", clear
    rebase `minyr'
    local yr `minyr'
    preserve
    while `yr'<=98 {
        restore, preserve
        keep captype jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
        sort captype
        save `capf`yr'', replace
        local yr=`yr'+1
    }
    restore
}
else {
    use "brazprod\deflate\capform-defl-ipa", clear
    keep captype
        gen str10 defltype="`type'"
        sort defltype
        merge defltype using "brazprod\deflate\general-defl", nokeep
        rebase 86
        drop defltype _merge
        sort captype
    local yr 86
    preserve
    while `yr'<=98 {
        restore, preserve
        keep captype jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
        save `capf`yr'', replace
        local yr=`yr'+1
    }
    restore
}
use "brazprod\deflate\general-defl", clear
rebase 86
    local yr 86
    preserve
    while `yr'<=98 {
        restore, preserve
        keep defltype inddefl jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
        save `inpc`yr'', replace
        local yr=`yr'+1
    }
    restore


/* Deflation Routines */
/*--------------------*/
/* Inflate flow variables to end-of-year values */
capture program drop monthcor
program define monthcor
    args varname yr
    gen byte _marker=1 if jan`yr'~=. & year==`yr'  /* No deflator, no change */
    replace _marker=2 if _marker==1 & (state==3 | state==4)
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr'+sep`yr'+oct`yr'+nov`yr'+dec`yr')) if _marker==1
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr'+sep`yr'+oct`yr'+nov`yr'+dec`yr')) if _marker==2 & chmon==12
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr'+sep`yr'+oct`yr'+nov`yr')) if _marker==2 & chmon==11
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr'+sep`yr'+oct`yr')) if _marker==2 & chmon==10
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr'+sep`yr')) if _marker==2 & chmon==9
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr'+aug`yr')) if _marker==2 & chmon==8
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr'+jul`yr')) if _marker==2 & chmon==7
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr'+jun`yr')) if _marker==2 & chmon==6
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr'+may`yr')) if _marker==2 & chmon==5
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr'+apr`yr')) if _marker==2 & chmon==4
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr'+mar`yr')) if _marker==2 & chmon==3
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr'+feb`yr')) if _marker==2 & chmon==2
    quietly replace `varname'=`varname'*(12*dec`yr'/(jan`yr')) if _marker==2 & chmon==1
    drop _marker
end
/* Deflate all flow variables to Aug-94 values */
capture program drop deflate
program define deflate
    args varname yr
    replace `varname'=`varname'/dec`yr' if dec`yr'~=. & year==`yr'
end

use `master', clear


/* Deflate Gross Investment Flows */
/*--------------------------------*/

/* PREMISES: INPC types of deflators */
gen str10 defltype="`type'"
local yr `minyr'
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort defltype
    merge defltype using `inpc`yr'', nokeep
    replace acqbl=. if (_merge==1 & year==`yr') | jan`yr'==.   /* No deflator, no observation */
    drop inddefl _merge
    if `moncor'==1 {
    monthcor acqbl `yr'
    }
    deflate  acqbl `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    local yr=`yr'+1
    }
replace acqbl=. if year<`minyr'
replace acqbl=. if year>`maxyr'      /* No deflator, no observation */
drop defltype

/* TOTAL: Capital formation deflator "total" */
gen str10 captype="total"
local yr `minyr'
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort captype
    merge captype using `capf`yr'', nokeep
    replace acqtot=. if (_merge==1 & year==`yr') | jan`yr'==.     /* No deflator, no observation */
    drop _merge
    if `moncor'==1 {
    monthcor acqtot `yr'
    }
    deflate  acqtot `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    local yr=`yr'+1
    }
replace acqtot=. if year<`minyr'
replace acqtot=. if year>`maxyr'     /* No deflator, no observation */ 
drop captype

/* OTHER: Capital formation deflator "other" */
gen str10 captype="other"
local yr `minyr'
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort captype
    merge captype using `capf`yr'', nokeep
    replace acqother=. if (_merge==1 & year==`yr') | jan`yr'==.     /* No deflator, no observation */
    drop _merge
    if `moncor'==1 {
    monthcor acqother `yr'
    }
    deflate  acqother `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    local yr=`yr'+1
    }
replace acqother=. if year<`minyr'
replace acqother=. if year>`maxyr'    /* No deflator, no observation */
drop captype

/* MACHINERY: Capital formation deflator "machinery" */
gen str10 captype="machinery"
local yr `minyr'
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort captype
    merge captype using `capf`yr'', nokeep
    replace acqmasum=. if (_merge==1 & year==`yr') | jan`yr'==.     /* No deflator, no observation */
    replace acqmadom=. if (_merge==1 & year==`yr') | jan`yr'==.
    replace acqmause=. if (_merge==1 & year==`yr') | jan`yr'==.
    replace acqmafor=. if (_merge==1 & year==`yr') | jan`yr'==.    
    drop _merge
    if `moncor'==1 {
    monthcor acqmasum `yr'
    monthcor acqmadom `yr'
    monthcor acqmause `yr'
    monthcor acqmafor `yr'
    }
    deflate  acqmasum `yr'
    deflate  acqmadom `yr'
    deflate  acqmause `yr'
    deflate  acqmafor `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    local yr=`yr'+1
    }
replace acqmasum=. if year<`minyr'   /* No deflator, no observation */
replace acqmasum=. if year>`maxyr'
replace acqmadom=. if year<`minyr'
replace acqmadom=. if year>`maxyr'
replace acqmause=. if year<`minyr'
replace acqmause=. if year>`maxyr'
replace acqmafor=. if year<`minyr'
replace acqmafor=. if year>`maxyr'
drop captype

/* VEHICLES: Capital formation deflator "vehicles"  */
gen str10 captype="vehicles"
local yr `minyr'
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort captype
    merge captype using `capf`yr'', nokeep
    replace acqveh=. if (_merge==1 & year==`yr') | jan`yr'==.     /* No deflator, no observation */
    drop _merge
    if `moncor'==1 {
    monthcor acqveh `yr'
    }
    deflate  acqveh `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    local yr=`yr'+1
    }
replace acqveh=. if year<`minyr'   /* No deflator, no observation */
replace acqveh=. if year>`maxyr'
drop captype

/* COMPUTERS: Capital formation deflator "computers"  */
gen str10 captype="computers"
local yr `minyr'
while `yr'<=`maxyr' {
    if `yr'==91 {local yr 92}
    sort captype
    merge captype using `capf`yr'', nokeep
    replace acqcomp=. if (_merge==1 & year==`yr') | jan`yr'==.     /* No deflator, no observation */
    drop _merge
    if `moncor'==1 {
    monthcor acqcomp `yr'
    }
    deflate  acqcomp `yr'
    drop jan`yr' feb`yr' mar`yr' apr`yr' may`yr' jun`yr' jul`yr' aug`yr' sep`yr' oct`yr' nov`yr' dec`yr'
    local yr=`yr'+1
    }
replace acqcomp=. if year<`minyr'   /* No deflator, no observation */
replace acqcomp=. if year>`maxyr'
drop captype

keep firm year acqtot-acqcomp
order firm year acqtot-acqcomp
sort firm year
save "brazprod\data\deflated\pia-invest-`ext'-`moncor'-`type'.dta", replace
