version 6.0
/*----------------------------------*/
/* Careful: Set max size to /k64000 */
/*----------------------------------*/

/* !! Make sure that `maxyr' was set to 98 in all preceding routines !! */

use "brazprod/data/pia-finl", clear

/* Choose Settings */
/*-----------------*/

local choice 3
/* Choice 1: Mesquita (and general) Deflators 90-98 */
/*        2: PIM-IBGE (and general) Deflators 86-98 */
/*        3: FGV-IPA (and general) Deflators 86-98 */
/*        4: FGV-DI (and general) Deflators 86-98 */
/*        9: Apply INPC to all variables */

local type "ipa-indtot"
/* Type of General Deflator: Used for stock variables
                              "igp-di", "inpc", "inpc-real", 
                              "ipa-indtot", "ipa-og", "ipa-transf"
        see "brazprod/deflate/general-defl.dta" 
        except for Cap Stock correction */

local saltype "ipa-indtot"
/* Type of Wage Deflator: Used for wages and rental rates only (see types above) */

local forpidx 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */

local corron 3
/* Corron 1: Correction Factors are Applied */
/*        2: Correction Factors are Not applied */
/*        3: Intermediate: Rebase capital stock before 90 to match 92 */

local minyr 86  /* Starting year */
local maxyr 98  /* Ending year */

local moncor 1
/* moncor 1: Month correction within year for flow variables */
/*        0: Do not execute month correction within year for flow variables */


if `choice'==1 {
    local ext "mesq"
    local minyr 90
    }
if `choice'==2 {local ext "pim"}
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {
    local ext "gen"
    local saltype="`type'"
    }
local fdfl = `forpidx'
if `fdfl'==0 { local fdfl = "" }


/* The output will be "brazprod/data/pia-use-`ext'`fdfl'-`moncor'-`type'" */
/*------------------------------------------------------------------------*/


/* Set inadmissible negative values to missing */
capture program drop corrneg
program define corrneg
  args varname
  replace `varname'=. if `varname'<0
end
corrneg balsum
corrneg crtot
corrneg crstsum
corrneg crstdom
corrneg crstfor
corrneg crltsum
corrneg crltdom
corrneg crltfor
corrneg labftot
corrneg labftop
corrneg labfwh
corrneg labfbl


/* Drop Select Variables */
/*-----------------------*/
keep  firm year state change cgcsuc born effborn econborn firstyr lastyr catentry catlife fstsusyr effextyr dpredcgc dprchg dprnotex indsctch indnoind niv100 niv80map region uf labftop labfwh labfbl
order firm year state change cgcsuc born effborn econborn firstyr lastyr catentry catlife fstsusyr effextyr dpredcgc dprchg dprnotex indsctch indnoind niv100 niv80map region uf labftop labfwh labfbl
sort firm year

/* Add-Vars */
/*----------*/
merge firm year using "brazprod/data/deflated/pia-invest-`ext'-`moncor'-`type'"
drop _merge
sort firm year
merge firm year using "brazprod/data/deflated/pia-capstock-`ext'-`type'-`corron'"
drop _merge
sort firm year
if `choice'~=9 {merge firm year using "brazprod/data/deflated/pia-flows-`ext'-`moncor'-`saltype'"}
    else       {merge firm year using "brazprod/data/deflated/pia-flows-`ext'-`moncor'-`type'"}
drop _merge
sort firm year
keep  firm year state change cgcsuc born effborn econborn firstyr lastyr catentry catlife fstsusyr effextyr dpredcgc dprchg dprnotex indsctch indnoind niv100 niv80map region uf sales difstock resales apimmo apmasum apdefer asrtimmo aslsimmo deprec fincost labftop labfwh labfbl wagetop wagewh wagebl acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp intmacq intmdif profit profoutd profinpd crtot
order firm year state change cgcsuc born effborn econborn firstyr lastyr catentry catlife fstsusyr effextyr dpredcgc dprchg dprnotex indsctch indnoind niv100 niv80map region uf sales difstock resales apimmo apmasum apdefer asrtimmo aslsimmo deprec fincost labftop labfwh labfbl wagetop wagewh wagebl acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp intmacq intmdif profit profoutd profinpd crtot

merge firm year using "brazprod/data/pia-ratios"
keep  firm year state change cgcsuc born effborn econborn firstyr lastyr catentry catlife fstsusyr effextyr dpredcgc dprchg dprnotex indsctch indnoind niv100 niv80map region uf sales difstock resales apimmo apmasum apdefer asrtimmo aslsimmo deprec fincost labftop labfwh labfbl wagetop wagewh wagebl acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp intmacq intmdif intfrrat profit profoutd profinpd crtot
order firm year state change cgcsuc born effborn econborn firstyr lastyr catentry catlife fstsusyr effextyr dpredcgc dprchg dprnotex indsctch indnoind niv100 niv80map region uf sales difstock resales apimmo apmasum apdefer asrtimmo aslsimmo deprec fincost labftop labfwh labfbl wagetop wagewh wagebl acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp intmacq intmdif intfrrat profit profoutd profinpd crtot
gen intmacqfor = intfrrat * intmacq
drop intfrrat
order firm year state change cgcsuc born effborn econborn firstyr lastyr catentry catlife fstsusyr effextyr dpredcgc dprchg dprnotex indsctch indnoind niv100 niv80map region uf sales difstock resales apimmo apmasum apdefer asrtimmo aslsimmo deprec fincost labftop labfwh labfbl wagetop wagewh wagebl acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp intmacq intmdif intmacqfor profit profoutd profinpd crtot
sort firm year


/* Foreign Inputs and Investments */
/*--------------------------------*/
if `fdfl'~=0 {
* gen _mu     = intmacqfor/intmacq if year>95
* gen _kappai = acqmafor/acqmasum  if year<96
drop intmacqfor acqmafor
sort firm year
merge firm year using "brazprod/data/deflated/pia-foracq-forppi`fdfl'-`moncor'"
* replace intmacq  = intmacqfor +     (1-_mu) * intmacq  if year>95
* replace acqmasum = acqmafor   + (1-_kappai) * acqmasum if year<96
replace intmacqfor = intmacq  if intmacqfor > intmacq & intmacqfor~=. & year>95
replace acqmafor   = acqmasum if acqmafor > acqmasum  & acqmafor~=.   & year<96
replace intmacqfor = . if year<96
replace acqmafor   = . if year>95
replace intmacqfor = 0 if intmacqfor==. & year>95
replace acqmafor   = 0 if acqmafor==.   & year<96
drop _*
}
order firm year state change cgcsuc born effborn econborn firstyr lastyr catentry catlife fstsusyr effextyr dpredcgc dprchg dprnotex indsctch indnoind niv100 niv80map region uf sales difstock resales apimmo apmasum apdefer asrtimmo aslsimmo deprec fincost labftop labfwh labfbl wagetop wagewh wagebl acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp intmacq intmdif intmacqfor profit profoutd profinpd crtot


/* Finalize */
/*----------*/
drop profoutd profinpd
order firm year state change cgcsuc born effborn econborn firstyr lastyr catentry catlife fstsusyr effextyr dpredcgc dprchg dprnotex indsctch indnoind niv100 niv80map region uf sales difstock resales apimmo apmasum apdefer asrtimmo aslsimmo deprec fincost labftop labfwh labfbl wagetop wagewh wagebl acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp intmacq intmdif intmacqfor profit crtot
sort firm year
if `choice'~=9 {
    save "brazprod/data/pia-use-`ext'`fdfl'-`moncor'-`type'-`saltype'-`corron'", replace
    }
else {
    save "brazprod/data/pia-use-`ext'`fdfl'-`moncor'-`type'-`corron'", replace
    }
