version 6.0
tempfile cap86 cap87 cap88 cap89 cap90

/* Set Missing Observations Properly */
/*-----------------------------------*/
capture program drop missobs
program define missobs
args i imax
while `i' < 10 {
    quietly replace v000`i'=. if v000`i'==-1
    local i = `i' + 1
}
while `i' < 100 {
    quietly replace v00`i'=. if v00`i'==-1
    local i = `i' + 1
}
while `i' < `imax' + 1 {
    quietly replace v0`i'=. if v0`i'==-1
    local i = `i' + 1
}
end


local yr=86    /* Do not use values other than 86, 87, 88, 89, 90 */
while `yr'<=90 {

insheet using "brazprod\pia-e\piae`yr'.csv", clear

missobs 1 158


/* General Information on the Firm */
/*---------------------------------*/
rename empresa firm
label var firm "Tax Number (CGC)"
format firm %8.0f

drop ano
gen byte year=`yr'
label var year "Calendar Year"
format year %2.0f

drop reg uf genero peso classe

label var niv100 "Sector of Firm (NIV100)"
rename v2101 state
label var state "State of Activity"
rename v2600 change
label var change "Change of Legal/Economic Status"

drop v2801
order firm year niv100 state change


/* Variables */
/*-----------*/
rename v0009 apimmo
label var apimmo "Assets (Total)"

rename v0041 aptot0
label var aptot0 "Beg. Y. - Assets (Total)"
egen apbl0=rsum(v0034 v0035)
label var apbl0 "Beg. Y. - Ground & Premises"
rename v0036 apmasum0
label var apmasum0 "Beg. Y. - Machinery (Sum)"
rename v0037 apveh0
label var apveh0 "Beg. Y. - Vehicles"
egen apother0=rsum(v0038 v0040)
label var apother0 "Beg. Y. - Other Assets"
rename v0039 apcomp0
label var apcomp0 "Beg. Y. - Computers"

egen aptotcr=rsum(v0064 v0087)
label var aptotcr "Correct - Assets (Total)"
egen apblcr=rsum(v0057 v0073 v0058 v0074)
label var apblcr "Correct - Ground & Premises"
egen apmasmcr=rsum(v0059 v0077)
label var apmasmcr "Correct - Machinery (Sum)"
egen apvehcr=rsum(v0060 v0081)
label var apvehcr "Correct - Vehicles"
egen apothrcr=rsum(v0061 v0084 v0063 v0086)
label var apothrcr "Correct - Other Assets"
egen apcompcr=rsum(v0062 v0085)
label var apcompcr "Correct - Computers"

rename v0056 acqtot
label var acqtot "Acquis. of Assets (Total)"
egen acqbl=rsum(v0042 v0043)
label var acqbl "Acquis. of Ground & Premises"
rename v0046 acqmasum
label var acqmasum "Acquis. of Machinery (Sum)"
rename v0047 acqmadom
label var acqmadom "Acquis. of Machinery: Domestic"
rename v0049 acqmause
label var acqmause "Acquis. of Machinery: Used"
rename v0048 acqmafor
label var acqmafor "Acquis. of Machinery: Foreign"
rename v0050 acqveh
label var acqveh "Acquis. of Vehicles"
egen acqother=rsum(v0053 v0055)
label var acqother "Acquis. of Other Assets"
rename v0054 acqcomp
label var acqcomp "Acquis. of Computers"

rename v0072 asltot
label var asltot "Sales of Assets (Total)"
egen aslbl=rsum(v0065 v0066)
label var aslbl "Sales of Ground & Premises"
rename v0067 aslmasum
label var aslmasum "Sales of Machinery"
rename v0068 aslveh
label var aslveh "Sales of Vehicles"
egen aslother=rsum(v0069 v0071)
label var aslother "Sales of Other Assets"
rename v0070 aslcomp
label var aslcomp "Sales of Computers"

rename v0094 aptotdp
label var aptotdp "Deprec. - Assets (Total)"
egen apbldp=rsum(v0088)
label var apbldp "Deprec. - Ground & Premises"
rename v0089 apmasmdp
label var apmasmdp "Deprec. - Machinery (Sum)"
rename v0090 apvehdp
label var apvehdp "Deprec. - Vehicles"
egen apothrdp=rsum(v0091 v0093)
label var apothrdp "Deprec. - Other Assets"
rename v0092 apcompdp
label var apcompdp "Deprec. - Computers"

rename v0102 aptot1
label var aptot1 "End Y. - Assets (Total)"
egen apbl1=rsum(v0095 v0096)
label var apbl1 "End Y. - Ground & Premises"
rename v0097 apmasum1
label var apmasum1 "End Y. - Machinery (Sum)"
rename v0098 apveh1
label var apveh1 "End Y. - Vehicles"
egen apother1=rsum(v0099 v0101)
label var apother1 "End Y. - Other Assets"
rename v0100 apcomp1
label var apcomp1 "End Y. - Computers"


/* Tmp. Save */
/*-----------*/
order firm year niv100 state change apimmo aptot1 apbl1 apmasum1 apveh1 apother1 apcomp1 aptot0 apbl0 apmasum0 apveh0 apother0 apcomp0 acqtot acqbl acqmasum acqmadom acqmause acqmafor acqveh acqother acqcomp asltot aslbl aslmasum aslveh aslother aslcomp aptotcr apblcr apmasmcr apvehcr apothrcr apcompcr aptotdp apbldp apmasmdp apvehdp apothrdp apcompdp
drop v0001-v0158
sort firm
save `cap`yr'', replace

local yr=`yr'+1
}

/* Append to one dataset */
/*-----------------------*/
use `cap86', clear
append using `cap87'
append using `cap88'
append using `cap89'
append using `cap90'
sort firm year
/* These data are extremely dirty: Execute the following lines to see */
/* egen test=rsum(aptot0 acqtot asltot aptotcr aptotdp) */
/* gen difftest=test-aptot1 */

save "brazprod\data\pia-e\capstruct-86-90", replace
