version 7
tempfile tmp1 tmp2 tmp3 tmp4


/* Choose Settings */
/*-----------------*/

foreach esttype in $esttype {
foreach rebase in 0 1 {

* local esttype "op"
/* Choice "ols": OLS         */
/*        "fe" : Within Eff. */
/*        "op" : Olley-Pakes */
/*        "gm" : Griliches-Mairesse */

* local rebase=1
/* Choice 1: Rebase logtfp by sector (after sector aggregation) so that 1986==1 before aggregation */
/* Choice 0: Only rebase at aggregation */

local subtract 0
/* Choice 1: Subtract b_K /gamma_K /kappa^f and b_M /gamma_M /mu^f */
/* Choice 0: Do not subtract */
global subtract = `subtract'

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext "gen"}

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {local outtype "valadd"}
if $out==2 {local outtype "output"}

global trd 0
/* Choice 3: Klette & Griliches 96 correction */
/* Choice 2: year dummies ON, trend variables OFF */
/* Choice 1: trend variables ON, time dummies OFF  */
/* Choice 0: trend variables and year dummies OFF */
if $trd==3 {local trdtype "kletgri"}
if $trd==2 {local trdtype "dyears"}
if $trd==1 {local trdtype "trend"}
if $trd==0 {local trdtype "notrend"}

global fe 2
/* Choice 2: fixed effects in OP estimation ON, AND KletGri96 inspired correction */
/* Choice 1: fixed effects in OP estimation ON  */
/* Choice 0: fixed effects in OP estimation OFF */
if $fe==2 & "`esttype'"~="op" {global fe 1}
if $fe~=0 {local fetype "fe"}
else      {local fetype "nofe"}
if $fe==2 {local feout="fecorr"}
else      {local feout="`fetype'"}

global polynl 3
/* Choice 2: Polynomial of 2nd order is used in Step 3 */
/* Choice 3: Polynomial of 3rd order is used in Step 3 */
/* Choice 4: Polynomial of 4th order is used in Step 3 */
/* Choice 5: Polynomial of 5th order is used in Step 3 */
/* Choice 6: Polynomial of 6th order is used in Step 3 */
local polynl=$polynl

global xeff 1
/* Choice 1: Approximate for X-efficiency choice by managers */
/* Choice 0: Approximate for X-efficiency choice by managers */
if $xeff {local xeff="x"}


local indir  "$indir"
local outdir "$outdir"
if "$simul"~="" { 
    local indir  "$simul" 
    local outdir "$simul/$outdir"
    capture mkdir "$simul/$outdir"
    }
else {
  capture mkdir "$outdir"
  }


/* Load Firm Characteristics */
/*---------------------------*/

use "`indir'/use-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", clear

preserve

local round=1
while `round' <=4 {  /* Create dataset in 2*2 rounds. 1/2: All, 3/4: Stayers, 1/3: Regions, 2/4: All Brazil (region==9) */
if `round'==2 | `round'==4 {replace region=9}
if `round'>=3 {
    gen double _laglntfp=.
    sort firm year
    foreach yr in 87 88 89 90 93 94 95 96 97 98 {
        by firm: replace _laglntfp=lntfp[_n-1] if year==`yr' & year[_n-1]==`yr'-1
        }
    foreach yr in 92 {
        by firm: replace _laglntfp=lntfp[_n-1] if year==`yr' & year[_n-1]==`yr'-2
        }
    keep if (lntfp~=. & _laglntfp~=.) | year==86 
    sort firm year
    by firm: replace indstay=. if year[_n-1]~=year-1
    gen byte sample=2
    drop _*
    }
else {gen byte sample=1}
/* browse firm year ind* if firm==50226455 | firm==50931211 */

/* Determine relative size for each firm in SECTOR & REGION */
egen double totsize=sum(fsize), by(niv50 region year)
label var totsize "Total `outtype'"
gen double sigma=fsize/totsize
/* egen double _check1=sum(sigma), by(niv50 region year)
   summ double _check*
   drop _* */

order firm year niv50 region lntfp lnlp bg* sigma

/* Determine CELLSIZE */
gen byte _dummy=1
egen double cellsize=sum(_dummy), by(niv50 region year)
label var cellsize "Cell size `outtype'"
drop _dummy*

/* Obtain Means (weighted Sums) */
gen double _gtfp  =sigma*lntfp
gen double _glp   =sigma*lnlp
gen double _gbgkap=sigma*bgkap
gen double _gbgmu =sigma*bgmu

sort firm year
by firm: gen byte _indsubsq=1 if year[_n+1]==year+1 | (year[_n+1]==92 & year==90)
gen double _gtfp_stay    = _gtfp    if indstay==1
gen double _glp_stay     = _glp     if indstay==1
by firm: gen double _laggtfp_stay = _gtfp if indstay[_n+1]==1 & _indsubsq==1
by firm: gen double _lagglp_stay  = _glp  if indstay[_n+1]==1 & _indsubsq==1
gen double _gtfp_entry   = _gtfp    if indentry==1
gen double _glp_entry    = _glp     if indentry==1
gen double _gtfp_resum   = _gtfp    if indresum==1
gen double _glp_resum    = _glp     if indresum==1
gen double _laggtfp_exit = _gtfp if indexit==1
gen double _lagglp_exit  = _glp  if indexit==1
gen double _laggtfp_susp = _gtfp if indsusp==1
gen double _lagglp_susp  = _glp  if indsusp==1
gen double _gtfp_miss    = _gtfp    if indstay~=1 & indentry~=1 & indresum~=1
gen double _glp_miss     = _glp     if indstay~=1 & indentry~=1 & indresum~=1
by firm: gen double _laggtfp_miss = _gtfp if (indstay[_n+1]~=1 | _indsubsq~=1) & indexit~=1 & indsusp~=1
by firm: gen double _lagglp_miss  = _glp  if (indstay[_n+1]~=1 | _indsubsq~=1) & indexit~=1 & indsusp~=1

sort firm year
by firm: gen double _gtfp_stay_tfpchg=sigma*(lntfp-lntfp[_n-1])       if indstay==1 & _indsubsq[_n-1]==1
by firm: gen double _gtfp_stay_sizchg=(sigma-sigma[_n-1])*lntfp[_n-1] if indstay==1 & _indsubsq[_n-1]==1
by firm: gen double _glp_stay_lpchg =sigma*(lnlp-lnlp[_n-1])        if indstay==1 & _indsubsq[_n-1]==1
by firm: gen double _glp_stay_sizchg=(sigma-sigma[_n-1])*lnlp[_n-1] if indstay==1 & _indsubsq[_n-1]==1
drop _indsubsq

foreach var in _gtfp _glp _gbgkap _gbgmu _gtfp_stay _laggtfp_stay _glp_stay _lagglp_stay _gtfp_entry _glp_entry _gtfp_resum _glp_resum _laggtfp_exit _lagglp_exit _laggtfp_susp _lagglp_susp _gtfp_miss _glp_miss _laggtfp_miss _lagglp_miss _gtfp_stay_tfpchg _gtfp_stay_sizchg _glp_stay_lpchg _glp_stay_sizchg { replace `var' = 0 if `var'==. } 

/* Check firm-level consistency */
qui summ, meanonly
local N = r(N)
egen double _chknow = rsum(_gtfp_stay _gtfp_entry _gtfp_resum _gtfp_miss)
egen double _chklag = rsum(_laggtfp_stay _laggtfp_exit _laggtfp_susp _laggtfp_miss)
egen double _chkstay= rsum(_gtfp_stay_tfpchg _gtfp_stay_sizchg)
sort firm year
by firm: gen double _difstay = _gtfp_stay - _laggtfp_stay[_n-1]
replace _difstay=0 if _difstay==.
count if int(_chknow*10000) ~= int(_gtfp*10000)
if r(N)>0 { keep if int(_chknow*10000) ~= int(_gtfp*10000)
            disp in red "Current TFP decomposition today does not add up to total in " in yellow r(N) "/`N' " in red " cases" 
            exit }
count if int(_chklag*10000) ~= int(_gtfp*10000)
if r(N)>0 { keep if int(_chklag*10000) ~= int(_gtfp*10000)
            disp in red "Lagged TFP decomposition does not add up to total in " in yellow r(N) "/`N' " in red " cases" 
            exit }
qui summ if indstay==1, meanonly
local N = r(N)
count if int(_chkstay*10000) ~= int(_difstay*10000)
/* browse firm year _chkstay _gtfp_stay_tfpchg _gtfp_stay_sizchg _difstay _gtfp_stay _laggtfp_stay ind* if firm==50226455 | firm==50931211 */

if r(N)>0 { sort firm year
            keep if int(_chkstay*10000) ~= int(_difstay*10000) | int(_chkstay[_n+1]*10000) ~= int(_difstay[_n+1]*10000)
            disp in red "TFP decomposition for Stayers does not add up to total in " in yellow r(N) "/`N' " in red " cases" 
            browse firm year _chkstay _gtfp_stay_tfpchg _gtfp_stay_sizchg _difstay _gtfp_stay _laggtfp_stay ind*
            exit }
sort firm year
/* browse firm year _chkstay _gtfp_stay_tfpchg _gtfp_stay_sizchg _difstay _gtfp_stay _laggtfp_stay ind* if niv50==4 & region==0 & year>=93 */

/* Collapse and rename as in /Papers/brazprod/stata/%5output/prodlevel-annual.do */
foreach var in stay entry exit resum susp { replace ind`var'=0 if ind`var'==. }
collapse (sum) sigma _gtfp _glp _gbgkap _gbgmu _gtfp_stay _laggtfp_stay _glp_stay _lagglp_stay _gtfp_entry _glp_entry _gtfp_resum _glp_resum _laggtfp_exit _lagglp_exit _laggtfp_susp _lagglp_susp _gtfp_miss _glp_miss _laggtfp_miss _lagglp_miss _gtfp_stay_tfpchg _gtfp_stay_sizchg _glp_stay_lpchg _glp_stay_sizchg (mean) gmlnva=lnvaladd totsize cellsize ind* sample, by(niv50 region year)
foreach var in tfp lp tfp_stay lp_stay tfp_entry lp_entry tfp_resum lp_resum tfp_miss lp_miss tfp_stay_tfpchg tfp_stay_sizchg lp_stay_lpchg lp_stay_sizchg { rename _g`var' gmln`var' } 
foreach var in bgkap bgmu { rename _g`var' gm`var' } 
foreach var in tfp_stay lp_stay tfp_exit lp_exit tfp_susp lp_susp tfp_miss lp_miss  { rename _lagg`var' laggmln`var' } 

/* Check aggregate consistency */
qui summ sigma, meanonly
if r(mean)~=1 { disp in red "Sigmas do not add up to 1 after collapse." 
                exit }
qui summ, meanonly
local N = r(N)
egen double _chknow = rsum(gmlntfp_stay gmlntfp_entry gmlntfp_resum gmlntfp_miss)
egen double _chklag = rsum(laggmlntfp_stay laggmlntfp_exit laggmlntfp_susp laggmlntfp_miss)
egen double _chkstay= rsum(gmlntfp_stay_tfpchg gmlntfp_stay_sizchg)
sort sample niv50 region year
by sample niv50 region: gen double _difstay = gmlntfp_stay - laggmlntfp_stay[_n-1]
count if int(_chknow*10000) ~= int(gmlntfp*10000)
if r(N)>0 { disp in red "TFP decomposition does not add up to total in " in yellow r(N) "/`N' " in red " cases" 
            exit }
count if int(_chklag*10000) ~= int(gmlntfp*10000)
if r(N)>0 { disp in red "LP decomposition does not add up to total in " in yellow r(N) "/`N' " in red " cases" 
            exit }
count if int(_chkstay*10000) ~= int(_difstay*10000) & _difstay~=.
if r(N)>0 { disp in red "TFP decomposition for Stayers does not add up to total in " in yellow r(N) "/`N' " in red " cases" 
            browse niv50 region year _chkstay gmlntfp_stay_tfpchg gmlntfp_stay_sizchg _difstay gmlntfp_stay laggmlntfp_stay if int(_chkstay*10000) ~= int(_difstay*10000) & _difstay~=.
            /* browse niv50 region year _chkstay gmlntfp_stay_tfpchg gmlntfp_stay_sizchg _difstay gmlntfp_stay laggmlntfp_stay if int(_chkstay*10000) == int(_difstay*10000) */
            exit }

label var gmlntfp "Average Log TFP"
label var gmlnlp  "Average Log LP"
label var gmlnva  "Average Value Added"
label var gmbgkap "Average betak * gk * kappa"
label var gmbgmu  "Average betam * gm * mu"

order sample niv50 region year gmlntfp gmlnlp gmlnva gmbg* totsize cellsize
sort  sample niv50 region year
compress
save `tmp`round'', replace
restore, preserve
local round=`round'+1
}

restore
use `tmp1', clear
append using `tmp2'
append using `tmp3'
append using `tmp4'
label var sample "1: all, 2: stayers"
sort sample niv50 region year

if `rebase'==1 {
    gen double _basetfp = gmlntfp if year==86
    gen double _baselp  = gmlnlp  if year==86
    gen double _basebgk = gmbgkap if year==86
    gen double _basebgm = gmbgmu  if year==96    
    replace _basebgk = - _basebgk if gmbgkap<0
    replace _basebgm = - _basebgm if gmbgmu <0
    egen double _spilltfp=max(_basetfp), by(niv50 region)
    egen double _spilllp =max(_baselp) , by(niv50 region)
    egen double _spillbgk=max(_basebgk), by(niv50 region)
    egen double _spillbgm=max(_basebgm), by(niv50 region)
    replace gmlntfp = gmlntfp/_spilltfp
    replace gmlnlp  = gmlnlp /_spilllp
    replace gmbgkap = gmbgkap/_spillbgk
    replace gmbgmu  = gmbgmu /_spillbgm
    drop _*
}

compress
preserve
    keep  sample niv50 year region gmlntfp gmlnlp gmlnva gmbgkap gmbgmu totsize cellsize
    order sample niv50 year region gmlntfp gmlnlp gmlnva gmbgkap gmbgmu totsize cellsize
    label var sample "1: all, 2: stayers"
    sort sample region niv50 year
    save "`outdir'/prodlevel`rebase'-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", replace
    /* cf _all using "brazprod/estimate/outsheet/prodlevel`rebase'-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", verbose */
restore, preserve
    /* keep sample niv50 year region gmlntfp gmlnlp laggmlntfp laggmlnlp gmlntfp_stay* laggmlntfp_stay gmlnlp_stay* laggmlnlp_stay gmlntfp_entry gmlnlp_entry gmlntfp_resum gmlnlp_resum laggmlntfp_exit laggmlnlp_exit laggmlntfp_susp laggmlnlp_susp gmlntfp_miss gmlnlp_miss laggmlntfp_miss laggmlnlp_miss totsize cellsize */
    sort sample region niv50 year
    save "`outdir'/proddecomp`rebase'-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", replace
restore

}
}
