version 7.0

/* Choose Settings */
/*-----------------*/

/* Sector with bootstrap */
global niv50 = "08 14 22 26 31"

local choice 3
/* Choice 3: FGV-IPA (and general) Deflators 86-98 */
/*        4: FGV-DI  (and general) Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di" }
if `choice'==9 {local ext "gen"}

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {local outtype "valadd"}
if $out==2 {local outtype "output"}

local  eps=1e-5     /* Convergence criterion in NLLS */

/* Combine estimates */
/*-------------------*/

capture program drop bstlst
program define bstlst
    args ext outtype run
    disp
    disp in gr "Successful bootstraps"
    disp in gr "---------------------"
    disp
    foreach niv in $niv50 {
        drop _all
        local exit 0
        local run = 1
        capture use "tfpest/estimate/bstrp/niv`niv'-`ext'`fdfl'-`outtype'-run`run'", clear
        while ~`exit' {
            local run = `run' + 1
            capture confirm file "tfpest/estimate/bstrp/niv`niv'-`ext'`fdfl'-`outtype'-run`run'.dta"
            if _rc==601 {local exit=1}
            else        {append using "tfpest/estimate/bstrp/niv`niv'-`ext'`fdfl'-`outtype'-run`run'"}
        }
        disp in gr "Total number of bootstraps for " in yellow "Niv`niv'" in green ": " in yellow _N
    /* bstat _all */
    }
end

bstlst `ext'`fdfl' `outtype' `run'
