version 7.0
set matsize 180
set logtype text
tempfile frmyr fitted

/* Choose Settings */
/*-----------------*/

* variable definitions from prior version where instrumented

global indepvar = "age age2 kappa1 mu dlbfmed dlbfbig dcapmed dcapbig kletgril fdiflw fdistk"
global candiv   = "dollar pidxbraz inflrate ppiworld ppioecd ppieu ppinam usa_bls argentina"

local lvlchg 9
/* Choice 9: Level regressions including kletgril */
if `lvlchg'==9 { 
    local depvar  = "lntfp"
    local variety = ""
    global endog  = "tariff reffpen kletgril"
    global baseiv = "dollar ppieu ppinam"
    }
local varmax : word count $endog
tokenize $endog
forvalues i = 1/`varmax' {
      local indepvar = subinword("$indepvar","``i''","",.)
      global indepvar = "`indepvar'"
      }

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext "gen"}

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {local outtype "valadd"}
if $out==2 {local outtype "output"}

global trd 0
/* Choice 3: Klette & Grilliches 96 correction */
/* Choice 2: year dummies ON, trend variables OFF */
/* Choice 1: trend variables ON, time dummies OFF  */
/* Choice 0: trend variables and year dummies OFF */
if $trd==3 {local trdtype "kletgri"}
if $trd==2 {local trdtype "dyears"}
if $trd==1 {local trdtype "trend"}
if $trd==0 {local trdtype "notrend"}

global maxiter=250  /* Maximum number of iterations in mle routines */

* confirm new file "tfpest/estimate/logs/olley-pakes-endogseclvl-`ext'`fdfl'.log"
* confirm new file "tfpest/estimate/seclvl-`ext'`fdfl'.dta"

capture log close
log using "tfpest/estimate/logs/olley-pakes-endogseclvl-`ext'`fdfl'.log", replace

use "brazprod/use-compl-`ext'`fdfl'", clear
keep firm year niv100 age 
gen age2    = age*age
label var age2 "Age^2 in years^2"
sort firm year
merge firm year using "brazprod/use-tfp-`ext'`fdfl'-dummies"
drop _m duf*
sort firm year
compress
save `frmyr'
use "brazprod/use-tfp-`ext'`fdfl'-`outtype'-`trdtype'", clear
sort firm year
merge firm year using `frmyr'
keep  firm year niv50 niv100 age age2 kappa1 mu dlbfmed dlbfbig dcapmed dcapbig reffpen tariff tariffrx inflrate realexch kletgril
order firm year niv50 niv100 age age2 kappa1 mu dlbfmed dlbfbig dcapmed dcapbig reffpen tariff tariffrx inflrate realexch kletgril
sort niv100 year
merge niv100 year using "brazprod/addl/ivs-sectoral", update
drop _m
sort year
merge year using "brazprod/addl/ivs-annual", update
drop _m
sort niv50 year
merge niv50 year using "brazprod/addl/fdi-use", nokeep update /* year 1991 missing */
drop _merge
keep  firm year niv50 niv100 $endog $candiv $indepvar
order firm year niv50 niv100 $endog $candiv $indepvar 
compress
sort firm year
by firm year: keep if _n==1 & firm~=.
drop if year>98 | year<86
sort firm year
tsset firm year

gen nivmix=niv100
replace nivmix = 415  if nivmix==410 | nivmix==420
replace nivmix = 1335 if nivmix==1330 | nivmix==1340
replace nivmix = 1515 if nivmix==1510 | nivmix==1520
replace nivmix = 2215 if nivmix==2210 | nivmix==2220
replace nivmix = 2615 if nivmix==2610 | nivmix==2620
replace nivmix = 3015 if nivmix==3010 | nivmix==3020
order niv100 nivmix year
preserve
    tempfile conc
    use "brazcomp/data/use-conc-ipa2", clear
    drop if regmix~=0
    drop regmix
    sort nivmix year
    compress
    save `conc'
restore
sort nivmix year
merge nivmix year using `conc', nokeep

* collapse (count) obs=firm (mean) niv50 $endog $candiv $indepvar, by(niv100 year)
* compress
* sort niv100 year
* tsset niv100 year


/* Year 91 */

expand 2 if year==92
sort firm year
by firm: replace year=91 if year==92 & year[_n+1]==92
foreach var in reffpen fdistk tariff kletgril herfsale {
  sort firm year
  by firm: replace `var' = (`var'[_n-1] + `var'[_n+1])/2 if year==91
  } 

/* Year 86 */

expand 2 if year==86
sort firm year
by firm: replace year=85 if year==86 & year[_n+1]==86


/* Data Saving */
/*-------------*/

keep  firm year reffpen fdistk tariff kletgril herfsale
order firm year reffpen fdistk tariff kletgril herfsale
sort firm year
compress
save "tfpest/seclvl-`ext'`fdfl'", replace

log close
