/* Load routines for OP Estimation */
version 7.0

/* Choose Settings */
/*-----------------*/

global trd 0
/* Choice 3: Klette & Griliches 96 correction */
/* Choice 2: year dummies ON, trend variables OFF */
/* Choice 1: trend variables ON, time dummies OFF  */
/* Choice 0: trend variables and year dummies OFF */



/* Olley-Pakes regressions, step 1 */
/*---------------------------------*/
capture program drop ollpak1
program define ollpak1
    args vars cond
    regress `vars' if `cond'
end
capture program drop ollpak1x
program define ollpak1x
    args vars cond
    xtreg `vars' if `cond', fe
    predict _u if `cond', u
    egen _fe=mean(_u) if `cond', by(firm)
    replace betafe=_fe if `cond'
    drop _u _fe
end


/* Olley-Pakes regressions, step 2 */
/*---------------------------------*/
capture program drop ollpak2a
program define ollpak2a
    args vars cond
    probit `vars' if `cond', iterate($maxiter)
end
capture program drop ollpak2b
program define ollpak2b
    args vars cond
    logit `vars' if `cond', iterate($maxiter)
end


/* Olley-Pakes regressions, step 3 */
/*---------------------------------*/
capture program drop nlstep3
program define nlstep3
    version 6.0
    if "`1'" == "?" {
        if $trd==1 {
            /* Up to 2nd order polynomials. Also correct code below. */
            if $polynl==2 {global S_1 "bkappa bk bq b00 b01 b02 b10 b11 b12 b20 b21 b22 btrd1 btrd2 btrd3"}
            /* Up to 3rd order polynomials. Also correct code below. */
            if $polynl==3 {global S_1 "bkappa bk bq b00 b01 b02 b03 b10 b11 b12 b13 b20 b21 b22 b23 b30 b31 b32 b33 btrd1 btrd2 btrd3"}
            /* Up to 4th order polynomials. Also correct code below. */
            if $polynl==4 {global S_1 "bkappa bk bq b00 b01 b02 b03 b04 b10 b11 b12 b13 b14 b20 b21 b22 b23 b24 b30 b31 b32 b33 b34 b40 b41 b42 b43 b44 btrd1 btrd2 btrd3"}
            /* Up to 5th order polynomials. Also correct code below. */
            if $polynl==5 {global S_1 "bkappa bk bq b00 b01 b02 b03 b04 b05 b10 b11 b12 b13 b14 b15 b20 b21 b22 b23 b24 b25 b30 b31 b32 b33 b34 b35 b40 b41 b42 b43 b44 b45 b50 b51 b52 b53 b54 b55 btrd1 btrd2 btrd3"}
            /* Up to 6th order polynomials. Also correct code below. */
            if $polynl==6 {global S_1 "bkappa bk bq b00 b01 b02 b03 b04 b05 b06 b10 b11 b12 b13 b14 b15 b16 b20 b21 b22 b23 b24 b25 b26 b30 b31 b32 b33 b34 b35 b36 b40 b41 b42 b43 b44 b45 b46 b50 b51 b52 b53 b54 b55 b56 b60 b61 b62 b63 b64 b65 b66 btrd1 btrd2 btrd3"}
            }
        else {
            /* Up to 2nd order polynomials. Also correct code below. */
            if $polynl==2 {global S_1 "bkappa bk bq b00 b01 b02 b10 b11 b12 b20 b21 b22"}
            /* Up to 3rd order polynomials. Also correct code below. */
            if $polynl==3 {global S_1 "bkappa bk bq b00 b01 b02 b03 b10 b11 b12 b13 b20 b21 b22 b23 b30 b31 b32 b33"}
            /* Up to 4th order polynomials. Also correct code below. */
            if $polynl==4 {global S_1 "bkappa bk bq b00 b01 b02 b03 b04 b10 b11 b12 b13 b14 b20 b21 b22 b23 b24 b30 b31 b32 b33 b34 b40 b41 b42 b43 b44"}
            /* Up to 5th order polynomials. Also correct code below. */
            if $polynl==5 {global S_1 "bkappa bk bq b00 b01 b02 b03 b04 b05 b10 b11 b12 b13 b14 b15 b20 b21 b22 b23 b24 b25 b30 b31 b32 b33 b34 b35 b40 b41 b42 b43 b44 b45 b50 b51 b52 b53 b54 b55"}
            /* Up to 6th order polynomials. Also correct code below. */
            if $polynl==6 {global S_1 "bkappa bk bq b00 b01 b02 b03 b04 b05 b06 b10 b11 b12 b13 b14 b15 b16 b20 b21 b22 b23 b24 b25 b26 b30 b31 b32 b33 b34 b35 b36 b40 b41 b42 b43 b44 b45 b46 b50 b51 b52 b53 b54 b55 b56 b60 b61 b62 b63 b64 b65 b66"}
            }
        global S_2 "Olley&Pakes 96: Step 3"
        global bkappa=$inikap
        global bk=$inik
        global bq=$iniq
        forvalues i = 0(1)$polynl {
            forvalues j = 0(1)$polynl {
                global b`i'`j'=0
                }
            }
        if $iniols==2 {
            capture quietly drop _nlini*            
            foreach i in 1 2 3 4 5 6 {quietly gen _nlini`i'0=(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^`i'      if e(sample)}
            foreach i in 1 2 3 4 5 6 {quietly gen _nlini`i'1=(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^`i'*`9'  if e(sample)}
            foreach i in 1 2 3 4 5 6 {quietly gen _nlini`i'2=(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^`i'*`10' if e(sample)}
            foreach i in 1 2 3 4 5 6 {quietly gen _nlini`i'3=(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^`i'*`11' if e(sample)}
            foreach i in 1 2 3 4 5 6 {quietly gen _nlini`i'4=(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^`i'*`12' if e(sample)}
            foreach i in 1 2 3 4 5 6 {quietly gen _nlini`i'5=(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^`i'*`13' if e(sample)}
            foreach i in 1 2 3 4 5 6 {quietly gen _nlini`i'6=(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^`i'*`14' if e(sample)}
            if $polynl==6 {quietly reg `e(depvar)' `2' `4' `6' `9' `10' `11' `12' `13' `14' _nlini* if e(sample)}
            if $polynl==5 {quietly reg `e(depvar)' `2' `4' `6' `9' `10' `11' `12' `13'      _nlini10-_nlini50 _nlini11-_nlini51 _nlini12-_nlini52 _nlini13-_nlini53 _nlini14-_nlini54 _nlini15-_nlini55 if e(sample)}
            if $polynl==4 {quietly reg `e(depvar)' `2' `4' `6' `9' `10' `11' `12'           _nlini10-_nlini40 _nlini11-_nlini41 _nlini12-_nlini42 _nlini13-_nlini43 _nlini14-_nlini44 if e(sample)}
            if $polynl==3 {quietly reg `e(depvar)' `2' `4' `6' `9' `10' `11'                _nlini10-_nlini30 _nlini11-_nlini31 _nlini12-_nlini32 _nlini13-_nlini33 if e(sample)}
            if $polynl<3  {quietly reg `e(depvar)' `2' `4' `6' `9' `10'                     _nlini10-_nlini20 _nlini11-_nlini21 _nlini12-_nlini22 if e(sample)}
            global b00=_b[_cons]
            global b01=  _b[`9']
            global b02= _b[`10']
            if $polynl>=3 {global b03= _b[`11']}
            if $polynl>=4 {global b04= _b[`12']}
            if $polynl>=5 {global b05= _b[`13']}
            if $polynl>=6 {global b06= _b[`14']}
            local i=1
            while `i' <= $polynl {
                local j=0
                while `j' <=$polynl {
                global b`i'`j'=_b[_nlini`i'`j']
                local j=`j'+1                                
                }
            local i=`i'+1
            }
            quietly drop _nlini*            
        }
        global btrd1=.05
        global btrd2=.05
        global btrd3=.05
        exit
    }
    erplc${polynl}${trd} _lefths kappa1 kappa0 lnapk1 lnapk0 lnapq1 lnapq0 phihat0 _prhat1 _prhat2 _prhat3 _prhat4 _prhat5 _prhat6 trend1 trend2 trend3
    replace `1'= _dpart0 + _dpart1 + _dpart2 + _dpart3 + _dpart4 + _dpart5 + _dpart6 + _dpart7
end

/* Auxiliary programs for step 3 */
if $trd~=1 {
capture program drop erplc2${trd}
program define erplc2${trd}
    replace _dpart0= $bkappa*`2' + $bk*`4' + $bq*`6' +  $b00 + $b01*`9' + $b02*`10'
    replace _dpart1= $b10*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')   + $b11*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`9'   + $b12*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`10'  
    replace _dpart2= $b20*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2 + $b21*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`9' + $b22*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`10'
end
capture program drop erplc3${trd}
program define erplc3${trd}
    replace _dpart0= $bkappa*`2' + $bk*`4' + $bq*`6' +  $b00 + $b01*`9' + $b02*`10' + $b03*`11'
    replace _dpart1= $b10*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')   + $b11*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`9'   + $b12*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`10'   + $b13*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`11'
    replace _dpart2= $b20*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2 + $b21*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`9' + $b22*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`10' + $b23*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`11'
    replace _dpart3= $b30*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3 + $b31*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`9' + $b32*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`10' + $b33*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`11'
end
capture program drop erplc4${trd}
program define erplc4${trd}
    replace _dpart0= $bkappa*`2' + $bk*`4' + $bq*`6' +  $b00 + $b01*`9' + $b02*`10' + $b03*`11'
    replace _dpart1= $b10*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')   + $b11*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`9'   + $b12*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`10'   + $b13*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`11'
    replace _dpart2= $b20*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2 + $b21*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`9' + $b22*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`10' + $b23*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`11'
    replace _dpart3= $b30*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3 + $b31*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`9' + $b32*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`10' + $b33*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`11'
    replace _dpart4= $b04*`12' + $b14*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`12' + $b24*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`12' + $b34*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`12' +                                                                                                  $b40*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4 + $b41*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`9' + $b42*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`10' + $b43*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`11' + $b44*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`12'
end
capture program drop erplc5${trd}
program define erplc5${trd}
    replace _dpart0= $bkappa*`2' + $bk*`4' + $bq*`6' +  $b00 + $b01*`9' + $b02*`10' + $b03*`11'
    replace _dpart1= $b10*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')   + $b11*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`9'   + $b12*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`10'   + $b13*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`11'
    replace _dpart2= $b20*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2 + $b21*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`9' + $b22*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`10' + $b23*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`11'
    replace _dpart3= $b30*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3 + $b31*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`9' + $b32*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`10' + $b33*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`11'
    replace _dpart4= $b04*`12' + $b14*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`12' + $b24*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`12' + $b34*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`12' +                                                                                                  $b40*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4 + $b41*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`9' + $b42*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`10' + $b43*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`11' + $b44*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`12'
    replace _dpart5= $b05*`13' + $b15*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`13' + $b25*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`13' + $b35*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`13' + $b45*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`13' +                                                  $b50*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5 + $b51*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5*`9' + $b52*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5*`10' + $b53*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5*`11' + $b54*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5*`12' + $b55*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5*`13'
end
capture program drop erplc6${trd}
program define erplc6${trd}
    replace _dpart0= $bkappa*`2' + $bk*`4' + $bq*`6' +  $b00 + $b01*`9' + $b02*`10' + $b03*`11'
    replace _dpart1= $b10*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')   + $b11*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`9'   + $b12*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`10'   + $b13*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`11'
    replace _dpart2= $b20*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2 + $b21*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`9' + $b22*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`10' + $b23*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`11'
    replace _dpart3= $b30*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3 + $b31*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`9' + $b32*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`10' + $b33*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`11'
    replace _dpart4= $b04*`12' + $b14*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`12' + $b24*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`12' + $b34*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`12' +                                                                                                  $b40*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4 + $b41*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`9' + $b42*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`10' + $b43*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`11' + $b44*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`12'
    replace _dpart5= $b05*`13' + $b15*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`13' + $b25*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`13' + $b35*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`13' + $b45*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`13' +                                                  $b50*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5 + $b51*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5*`9' + $b52*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5*`10' + $b53*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5*`11' + $b54*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5*`12' + $b55*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5*`13'
    replace _dpart6= $b06*`14' + $b16*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`14' + $b26*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`14' + $b36*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`14' + $b46*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`14' + $b56*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5*`14' +  $b60*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^6 + $b61*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^6*`9' + $b62*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^6*`10' + $b63*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^6*`11' + $b64*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^6*`12' + $b65*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^6*`13' + $b66*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^6*`14'
end
}
else {
capture program drop erplc21
program define erplc21
    replace _dpart0= $bkappa*`2' + $bk*`4' + $bq*`6' +  $b00 + $b01*`9' + $b02*`10'
    replace _dpart1= $b10*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')   + $b11*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`9'   + $b12*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`10'
    replace _dpart2= $b20*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2 + $b21*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`9' + $b22*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`10'
    replace _dpart7= $btrd1*`15' + $btrd2*`16' + $btrd3*`17'
end
capture program drop erplc31
program define erplc31
    replace _dpart0= $bkappa*`2' + $bk*`4' + $bq*`6' +  $b00 + $b01*`9' + $b02*`10' + $b03*`11'
    replace _dpart1= $b10*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')   + $b11*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`9'   + $b12*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`10'   + $b13*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`11'
    replace _dpart2= $b20*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2 + $b21*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`9' + $b22*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`10' + $b23*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`11'
    replace _dpart3= $b30*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3 + $b31*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`9' + $b32*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`10' + $b33*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`11'
    replace _dpart7= $btrd1*`15' + $btrd2*`16' + $btrd3*`17'
end
capture program drop erplc41
program define erplc41
    replace _dpart0= $bkappa*`2' + $bk*`4' + $bq*`6' +  $b00 + $b01*`9' + $b02*`10' + $b03*`11'
    replace _dpart1= $b10*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')   + $b11*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`9'   + $b12*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`10'   + $b13*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`11'
    replace _dpart2= $b20*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2 + $b21*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`9' + $b22*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`10' + $b23*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`11'
    replace _dpart3= $b30*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3 + $b31*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`9' + $b32*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`10' + $b33*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`11'
    replace _dpart4= $b04*`12' + $b14*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`12' + $b24*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`12' + $b34*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`12' +                                                                                                  $b40*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4 + $b41*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`9' + $b42*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`10' + $b43*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`11' + $b44*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`12'
    replace _dpart7= $btrd1*`15' + $btrd2*`16' + $btrd3*`17'
end
capture program drop erplc51
program define erplc51
    replace _dpart0= $bkappa*`2' + $bk*`4' + $bq*`6' +  $b00 + $b01*`9' + $b02*`10' + $b03*`11'
    replace _dpart1= $b10*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')   + $b11*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`9'   + $b12*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`10'   + $b13*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`11'
    replace _dpart2= $b20*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2 + $b21*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`9' + $b22*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`10' + $b23*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`11'
    replace _dpart3= $b30*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3 + $b31*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`9' + $b32*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`10' + $b33*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`11'
    replace _dpart4= $b04*`12' + $b14*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`12' + $b24*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`12' + $b34*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`12' +                                                                                                  $b40*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4 + $b41*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`9' + $b42*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`10' + $b43*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`11' + $b44*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`12'
    replace _dpart5= $b05*`13' + $b15*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`13' + $b25*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`13' + $b35*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`13' + $b45*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`13' +                                                  $b50*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5 + $b51*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5*`9' + $b52*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5*`10' + $b53*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5*`11' + $b54*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5*`12' + $b55*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5*`13'
    replace _dpart7= $btrd1*`15' + $btrd2*`16' + $btrd3*`17'
end
capture program drop erplc61
program define erplc61
    replace _dpart0= $bkappa*`2' + $bk*`4' + $bq*`6' +  $b00 + $b01*`9' + $b02*`10' + $b03*`11'
    replace _dpart1= $b10*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')   + $b11*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`9'   + $b12*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`10'   + $b13*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`11'
    replace _dpart2= $b20*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2 + $b21*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`9' + $b22*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`10' + $b23*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`11'
    replace _dpart3= $b30*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3 + $b31*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`9' + $b32*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`10' + $b33*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`11'
    replace _dpart4= $b04*`12' + $b14*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`12' + $b24*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`12' + $b34*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`12' +                                                                                                  $b40*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4 + $b41*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`9' + $b42*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`10' + $b43*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`11' + $b44*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`12'
    replace _dpart5= $b05*`13' + $b15*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`13' + $b25*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`13' + $b35*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`13' + $b45*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`13' +                                                  $b50*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5 + $b51*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5*`9' + $b52*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5*`10' + $b53*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5*`11' + $b54*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5*`12' + $b55*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5*`13'
    replace _dpart6= $b06*`14' + $b16*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')*`14' + $b26*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^2*`14' + $b36*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^3*`14' + $b46*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^4*`14' + $b56*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^5*`14' +  $b60*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^6 + $b61*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^6*`9' + $b62*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^6*`10' + $b63*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^6*`11' + $b64*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^6*`12' + $b65*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^6*`13' + $b66*(`8'-$bkappa*`3'-$bk*`5'-$bq*`7')^6*`14'
    replace _dpart7= $btrd1*`15' + $btrd2*`16' + $btrd3*`17'
end
}


/* Output routines for Olley-Pakes estimation */
/*--------------------------------------------*/

/* Output of step 1 results */
capture program drop outstp1
program define outstp1
    args grp nivdsp
    if `grp'==1 {matrix stp1bet=beta'}
    else {matrix stp1bet=stp1bet,beta'}
    matname stp1bet "niv`nivdsp'", columns(`grp') explicit
    matrix sdv=vecdiag(e(V))'
    local j 1
    while `j'<=rowsof(sdv) {
        matrix sdv[`j',1]=sqrt(sdv[`j',1])
        local j=`j'+1
    }
    if `grp'==1 {matrix stp1sdv=sdv}
    else {matrix stp1sdv=stp1sdv,sdv}
    matname stp1sdv "niv`nivdsp'", columns(`grp') explicit
    replace betabl= beta[1,1] if group==`grp'
    global betabl= beta[1,1]
    replace betawh= beta[1,2] if group==`grp'
    global betawh= beta[1,2]
    replace bsdvbl= sqrt(var[1,1]) if group==`grp'
    replace bsdvwh= sqrt(var[2,2]) if group==`grp'
    replace bcovlb= var[1,2]       if group==`grp'
    if $out==2 {replace betamu  = beta[1,3] if group==`grp'
                replace betaintm= beta[1,4] if group==`grp'
                replace bsdvmu  = sqrt(var[3,3]) if group==`grp'
                replace bsdvintm= sqrt(var[4,4]) if group==`grp'
                replace bcovimbl= var[1,4]       if group==`grp'
                replace bcovimwh= var[2,4]       if group==`grp'
            }
    if $trd==3 & $out==1 {replace bklegri= beta[1,9] if group==`grp'
                          replace bsdvklegri= sqrt(var[9,9]) if group==`grp'}
    if $trd==3 & $out==2 {replace bklegri= beta[1,11] if group==`grp'
                          replace bsdvklegri= sqrt(var[11,11]) if group==`grp'}
    if $trd==2 & $out==1 {
            replace byr87= beta[1,9] if group==`grp'
            replace byr88= beta[1,10] if group==`grp'
            replace byr89= beta[1,11] if group==`grp'
            replace byr90= beta[1,12] if group==`grp'
            replace byr92= beta[1,13] if group==`grp'
            replace byr93= beta[1,14] if group==`grp'
            replace byr94= beta[1,15] if group==`grp'
            replace byr95= beta[1,16] if group==`grp'
            replace byr96= beta[1,17] if group==`grp'
            replace byr97= beta[1,18] if group==`grp'
            replace byr98= beta[1,19] if group==`grp'
            }
    if $trd==2 & $out==2 {
            replace byr87= beta[1,11] if group==`grp'
            replace byr88= beta[1,12] if group==`grp'
            replace byr89= beta[1,13] if group==`grp'
            replace byr90= beta[1,14] if group==`grp'
            replace byr92= beta[1,15] if group==`grp'
            replace byr93= beta[1,16] if group==`grp'
            replace byr94= beta[1,17] if group==`grp'
            replace byr95= beta[1,18] if group==`grp'
            replace byr96= beta[1,19] if group==`grp'
            replace byr97= beta[1,20] if group==`grp'
            replace byr98= beta[1,21] if group==`grp'
            }
    matrix drop sdv
end

/* Output of step 3 results */
capture program drop outstp3
program define outstp3
    args grp nivdsp
    if $out==1 {local noncap=1-$betawh-$betabl}
    if $out==2 {local noncap=1-$betawh-$betabl-$betaintm}
    test _b[bk] + _b[bq] = `noncap'
    replace betakappa=$bkappa if group==`grp'
    replace betak    =$bk     if group==`grp'
    replace betaq    =$bq     if group==`grp'
    if $trd==1 {
        replace btrd1=$btrd1 if group==`grp'
        replace btrd2=$btrd2 if group==`grp'
        replace btrd3=$btrd3 if group==`grp'
        }
    matrix beta=e(b)
    if `grp'==1 {matrix stp3bet=beta'}
    else {matrix stp3bet=stp3bet,beta'}
    matname stp3bet "niv`nivdsp'", columns(`grp') explicit
    matrix sdv=vecdiag(e(V))'
    local j 1
    while `j'<=rowsof(sdv) {
        matrix sdv[`j',1]=sqrt(sdv[`j',1])
        local j=`j'+1
    }
    if `grp'==1 {matrix stp3sdv=sdv}
    else {matrix stp3sdv=stp3sdv,sdv}
    matname stp3sdv "niv`nivdsp'", columns(`grp') explicit
    matrix var=e(V)
    replace bsdvkap =sqrt(var[1,1]) if group==`grp'
    replace bsdvk   =sqrt(var[2,2]) if group==`grp'
    replace bsdvq   =sqrt(var[3,3]) if group==`grp'
    replace bcovk   =var[2,3]       if group==`grp'
    replace obsnum=e(N) if group==`grp'
    matrix drop beta sdv var
end


/* OLS/FE regressions */
/*--------------------*/
capture program drop excreg1
program define excreg1
    args vars cond test
    regress `vars' if `cond'
    test `test'
    matrix beta=e(b)
    matrix var=e(V)
    replace olsnum  = e(N)      if `cond'
    replace olskappa= beta[1,1] if `cond'
    replace olsbetk = beta[1,2] if `cond'
    replace olsbetq = beta[1,3] if `cond'
    replace olsbetbl= beta[1,4] if `cond'
    replace olsbetwh= beta[1,5] if `cond'
    if $iniols==1 {
        global  inikap = beta[1,1]
        global  inik   = beta[1,2]
        global  iniq   = beta[1,3]
        }
    if $out==2 {replace olsmu= beta[1,6] if `cond'
                replace olsbetintm= beta[1,7] if `cond'
                if $trd==3 {
                    replace olsklegr= beta[1,8] if `cond'
                    }
                if $trd==1 {
                    replace olstrd1= beta[1,8] if `cond'
                    replace olstrd2= beta[1,9] if `cond'
                    replace olstrd3= beta[1,10] if `cond'
                    }
                }
    else        {if $trd==3 {
                    replace olsklegr= beta[1,6] if `cond'
                    }
                 if $trd==1 {
                    replace olstrd1= beta[1,6] if `cond'
                    replace olstrd2= beta[1,7] if `cond'
                    replace olstrd3= beta[1,8] if `cond'
                    }
                }
    replace olssdvkap= sqrt(var[1,1]) if `cond'
    replace olssdvk  = sqrt(var[2,2]) if `cond'
    replace olssdvq  = sqrt(var[3,3]) if `cond'
    replace olscovk  = var[2,3]       if `cond'
    replace olssdvbl = sqrt(var[4,4]) if `cond'
    replace olssdvwh = sqrt(var[5,5]) if `cond'
    replace olscovlb = var[4,5]       if `cond'
    if $trd==3 {replace olssdvklegr = sqrt(var[6,6]) if `cond'}
    if $out==2 {replace olssdvmu  = sqrt(var[6,6]) if `cond'
                replace olssdvintm= sqrt(var[7,7]) if `cond'
                replace olscovimbl= var[7,4]       if `cond'
                replace olscovimwh= var[7,5]       if `cond'
                }
    xtreg   `vars' if `cond', fe
    test `test'
    matrix beta=e(b)
    matrix var=e(V)
    replace winum  = e(N)      if `cond'
    replace wikappa= beta[1,1] if `cond'
    replace wibetk = beta[1,2] if `cond'
    replace wibetq = beta[1,3] if `cond'
    replace wibetbl= beta[1,4] if `cond'
    replace wibetwh= beta[1,5] if `cond'
    if $iniols==0 | $iniols==2 {
        global  inikap = beta[1,1]
        global  inik   = beta[1,2]
        global  iniq   = beta[1,3]
        }
    if $out==2 {replace wimu     = beta[1,6] if `cond'
                replace wibetintm= beta[1,7] if `cond'
                if $trd==3 {
                    replace wiklegri= beta[1,8] if `cond'
                    }
                if $trd==1 {
                    replace witrd1= beta[1,8] if `cond'
                    replace witrd2= beta[1,9] if `cond' 
                    replace witrd3= beta[1,10] if `cond'
                    }
                }
    else        {if $trd==3 {
                    replace wiklegri= beta[1,6] if `cond'
                    }
                 if $trd==1 {
                    replace witrd1= beta[1,6] if `cond'
                    replace witrd2= beta[1,7] if `cond'
                    replace witrd3= beta[1,8] if `cond'
                    }
                }
    replace wisdvkap= sqrt(var[1,1]) if `cond'
    replace wisdvk  = sqrt(var[2,2]) if `cond'
    replace wisdvq  = sqrt(var[3,3]) if `cond'
    replace wicovk  = var[2,3]       if `cond'
    replace wisdvbl = sqrt(var[4,4]) if `cond'
    replace wisdvwh = sqrt(var[5,5]) if `cond'
    replace wicovlb = var[4,5]       if `cond'
    if $trd==3 {replace wisdvklegri = sqrt(var[6,6]) if `cond'}
    if $out==2 {replace wisdvmu  = sqrt(var[6,6]) if `cond'
                replace wisdvintm= sqrt(var[7,7]) if `cond'
                replace wicovimbl= var[7,4]       if `cond'
                replace wicovimwh= var[7,5]       if `cond'
                }
end


/* Creation of polynomial series */
/*-------------------------------*/
capture program drop poly2
program define poly2
  args var1 var2 var3 var4 var5
  gen _p01=`var1'^2
  gen _p02=`var2'^2
  gen _p03=`var3'^2
  gen _p04=`var4'^2
  gen _p05=`var5'^2
  gen _p06=`var1'*`var2'
  gen _p07=`var1'*`var3'
  gen _p08=`var1'*`var4'
  gen _p09=`var1'*`var5'
  gen _p10=`var2'*`var3'
  gen _p11=`var2'*`var4'
  gen _p12=`var2'*`var5'
  gen _p13=`var3'*`var4'
  gen _p14=`var3'*`var5'
  gen _p15=`var4'*`var5'
end
capture program drop poly3
program define poly3
  args var1 var2 var3 var4 var5
  gen _p16=`var1'^3
  gen _p17=`var2'^3
  gen _p18=`var3'^3
  gen _p19=`var4'^3
  gen _p20=`var5'^3
  gen _p21=(`var1'^2)*`var2'
  gen _p22=(`var1'^2)*`var3'
  gen _p23=(`var1'^2)*`var4'
  gen _p24=(`var1'^2)*`var5'
  gen _p25=(`var2'^2)*`var1'
  gen _p26=(`var2'^2)*`var3'
  gen _p27=(`var2'^2)*`var4'
  gen _p28=(`var2'^2)*`var5'
  gen _p29=(`var3'^2)*`var1'
  gen _p30=(`var3'^2)*`var2'
  gen _p31=(`var3'^2)*`var4'
  gen _p32=(`var3'^2)*`var5'
  gen _p33=(`var4'^2)*`var1'
  gen _p34=(`var4'^2)*`var2'
  gen _p35=(`var4'^2)*`var3'
  gen _p36=(`var4'^2)*`var5'
  gen _p37=(`var5'^2)*`var1'
  gen _p38=(`var5'^2)*`var2'
  gen _p39=(`var5'^2)*`var3'
  gen _p40=(`var5'^2)*`var4'
  gen _p41=`var1'*`var2'*`var3'
  gen _p42=`var1'*`var2'*`var4'
  gen _p43=`var1'*`var2'*`var5'
  gen _p44=`var1'*`var3'*`var4'
  gen _p45=`var1'*`var3'*`var5'
  gen _p46=`var1'*`var4'*`var5'
  gen _p47=`var2'*`var3'*`var4'
  gen _p48=`var2'*`var3'*`var5'
  gen _p49=`var2'*`var4'*`var5'
  gen _p50=`var3'*`var4'*`var5'
end
capture program drop poly4
program define poly4
  args var1 var2 var3 var4 var5
  gen _p51=`var1'^4
  gen _p52=`var2'^4
  gen _p53=`var3'^4  
  gen _p54=`var4'^4
  gen _p55=`var5'^4
  gen _p56=(`var1'^3)*`var2'
  gen _p57=(`var1'^3)*`var3'
  gen _p58=(`var1'^3)*`var4'
  gen _p59=(`var1'^3)*`var5'
  gen _p60=(`var2'^3)*`var1'
  gen _p61=(`var2'^3)*`var3'
  gen _p62=(`var2'^3)*`var4'
  gen _p63=(`var2'^3)*`var5'
  gen _p64=(`var3'^3)*`var1'
  gen _p65=(`var3'^3)*`var2'
  gen _p66=(`var3'^3)*`var4'
  gen _p67=(`var3'^3)*`var5'
  gen _p68=(`var4'^3)*`var1'
  gen _p69=(`var4'^3)*`var2'
  gen _p70=(`var4'^3)*`var3'
  gen _p71=(`var4'^3)*`var5'
  gen _p72=(`var5'^3)*`var1'
  gen _p73=(`var5'^3)*`var2'
  gen _p74=(`var5'^3)*`var3'
  gen _p75=(`var5'^3)*`var4'
  gen _p76=(`var1'^2)*(`var2'^2)
  gen _p77=(`var1'^2)*(`var3'^2)
  gen _p78=(`var1'^2)*(`var4'^2)
  gen _p79=(`var1'^2)*(`var5'^2)
  gen _p80=(`var2'^2)*(`var1'^2)
  gen _p81=(`var2'^2)*(`var3'^2)
  gen _p82=(`var2'^2)*(`var4'^2)
  gen _p83=(`var2'^2)*(`var5'^2)
  gen _p84=(`var3'^2)*(`var1'^2)
  gen _p85=(`var3'^2)*(`var2'^2)
  gen _p86=(`var3'^2)*(`var4'^2)
  gen _p87=(`var3'^2)*(`var5'^2)
  gen _p88=(`var4'^2)*(`var1'^2)
  gen _p89=(`var4'^2)*(`var2'^2)
  gen _p90=(`var4'^2)*(`var3'^2)
  gen _p91=(`var4'^2)*(`var5'^2)
  gen _p92=(`var5'^2)*(`var1'^2)
  gen _p93=(`var5'^2)*(`var2'^2)
  gen _p94=(`var5'^2)*(`var3'^2)
  gen _p95=(`var5'^2)*(`var4'^2)
  gen _p96 =(`var1'^2)*`var2'*`var3'
  gen _p97 =(`var1'^2)*`var2'*`var4'
  gen _p98 =(`var1'^2)*`var2'*`var5'
  gen _p99 =(`var1'^2)*`var3'*`var4'
  gen _p100=(`var1'^2)*`var3'*`var5'
  gen _p101=(`var1'^2)*`var4'*`var5'
  gen _p102=(`var2'^2)*`var1'*`var3'
  gen _p103=(`var2'^2)*`var1'*`var4'
  gen _p104=(`var2'^2)*`var1'*`var5'
  gen _p105=(`var2'^2)*`var3'*`var4'
  gen _p106=(`var2'^2)*`var3'*`var5'
  gen _p107=(`var2'^2)*`var4'*`var5'
  gen _p108=(`var3'^2)*`var1'*`var2'
  gen _p109=(`var3'^2)*`var1'*`var4'
  gen _p110=(`var3'^2)*`var1'*`var5'
  gen _p111=(`var3'^2)*`var2'*`var4'
  gen _p112=(`var3'^2)*`var2'*`var5'
  gen _p113=(`var3'^2)*`var4'*`var5'
  gen _p114=(`var4'^2)*`var1'*`var2'
  gen _p115=(`var4'^2)*`var1'*`var3'
  gen _p116=(`var4'^2)*`var1'*`var5'
  gen _p117=(`var4'^2)*`var2'*`var3'
  gen _p118=(`var4'^2)*`var2'*`var4'
  gen _p119=(`var4'^2)*`var3'*`var5'
  gen _p120=(`var5'^2)*`var1'*`var2'
  gen _p121=(`var5'^2)*`var1'*`var3'
  gen _p122=(`var5'^2)*`var1'*`var4'
  gen _p123=(`var5'^2)*`var2'*`var3'
  gen _p124=(`var5'^2)*`var2'*`var4'
  gen _p125=(`var5'^2)*`var3'*`var4'
end
