version 7
set matsize 180
set logtype text

/* Choose Settings */
/*-----------------*/

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext "gen"}

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {local outtype "valadd"}
if $out==2 {local outtype "output"}

global trd 0
/* Choice 3: Klette & Grilliches 96 correction */
/* Choice 2: year dummies ON, trend variables OFF */
/* Choice 1: trend variables ON, time dummies OFF  */
/* Choice 0: trend variables and year dummies OFF */
if $trd==3 {local trdtype "kletgri"}
if $trd==2 {local trdtype "dyears"}
if $trd==1 {local trdtype "trend"}
if $trd==0 {local trdtype "notrend"}

global maxiter=250  /* Maximum number of iterations in mle routines */

capture mkdir "tfpest/estimate/estmat/all"

use "tfpest/use-tfp-`ext'`fdfl'-`outtype'-`trdtype'", clear
keep firm year niv50 phat* indsurvv reffpen tariff realexch inflrate lnage lnapk1 lnapq1 ntkinv ntqinv 
local yrmax=98

sort firm year
merge firm year using "brazprod/exp-imp/exp-imp", nokeep
keep firm year niv50 phat* indsurvv reffpen tariff realexch inflrate lnage lnapk1 lnapq1 ntkinv ntqinv indexp
replace indexp=0 if indexp==.
sort firm year


/* Estimation across all sectors */
/*-------------------------------*/

capture log close
log using "tfpest/estimate/logs/olley-pakes-survvprob-all-`ext'`fdfl'.log", replace

gen byte group = 0
local grp 0


/* OP Step 2. Probability of Exit (across all sectors for reporting) */
/*-------------------------------------------------------------------*/
/* Prepare step 2 estimation: exit variable resetting */
quietly poly2 ntkinv ntqinv lnage lnapk1 lnapq1
quietly poly3 ntkinv ntqinv lnage lnapk1 lnapq1
quietly poly4 ntkinv ntqinv lnage lnapk1 lnapq1
gen byte _mark=.  /* Mark observations that will be missing in logit/probit estimation */
local i 1
while `i'<=31 {
    local ext="`i'"
    if `i'<10 {local ext="0`i'"}
    sort firm year
    quietly replace _mark=1 if _p`ext'==.
    local i = `i'+1
    }
sort firm year
quietly by firm: replace indsurvv=0 if indsurvv[_n+1]==0 & _mark[_n+1]==1
drop _mark

/* Begin actual step 2 estimation */
sort firm year
local rvars "indsurvv reffpen tariff realexch inflrate lnage lnapk1 lnapq1 ntkinv ntqinv _p*"

ollpak2a "`rvars'" "group==`grp' & year<91"
est2vec prob, v(`rvars' indexp _cons) replace name(allsecbef91)
ollpak2a "`rvars'" "group==`grp' & year>91"
est2vec _tmp, addto(prob) nokeep replace name(allsecaft91)
ollpak2b "`rvars'" "group==`grp' & year<91"
est2vec logt, v(`rvars' indexp _cons) replace name(allsecbef91)
ollpak2b "`rvars'" "group==`grp' & year>91"
est2vec _tmp, addto(logt) nokeep replace name(allsecaft91)

ollpak2a "`rvars' indexp" "group==`grp' & year>89"
est2vec _tmp, addto(prob) nokeep replace name(allsecaft88exp)
ollpak2b "`rvars' indexp" "group==`grp' & year>89"
est2vec _tmp, addto(logt) nokeep replace name(allsecaft88exp)
ollpak2a "`rvars'" "group==`grp'"
est2vec _tmp, addto(prob) nokeep replace name(allsecaft85)
ollpak2b "`rvars'" "group==`grp'"
est2vec _tmp, addto(logt) nokeep replace name(allsecaft85)

log close

preserve
foreach type in b se e {
    drop _all
    matsave prob_`type', path("tfpest/estimate/estmat/all") replace
    drop _all
    matsave logt_`type', path("tfpest/estimate/estmat/all") replace
}
restore
