version 7
set matsize 180

/* Choose Settings */
/*-----------------*/

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext "gen"}

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {local outtype "valadd"}
if $out==2 {local outtype "output"}


/* Load variable names and save for est2tex */

insheet using "tfpest/summ/regressor-list.tex", delimiter("&") clear
rename v1 _rowname
rename v2 _rowlbl
replace _rowname = trim(_rowname)
replace _rowlbl = trim(_rowlbl)
drop if _rowname=="" & _rowlbl==""
sort _rowname
compress
save "c:/texdocs/tfpest/stata-origs/eoplpols_rowlbl", replace


/* Load estimate matrices and bootstrap data */

foreach type in b se e r {
    drop _all
    matload lp_`type', path("tfpest/estimate/estmat/mat-`ext'`fdfl'-`outtype'") over
    drop _all
    matload ols_`type', path("tfpest/estimate/estmat/mat-`ext'`fdfl'-`outtype'") over
    drop _all
    matload op_`type', path("tfpest/estimate/estmat/mat-`ext'`fdfl'-`outtype'") over
    drop _all
    matload eop_`type', path("tfpest/estimate/estmat/mat-`ext'`fdfl'-`outtype'") over
}
capture matrix drop lp_se1
matrix rename lp_se lp_se1
capture matrix drop ols_se1
matrix rename ols_se ols_se1
capture matrix drop op_se1
matrix rename op_se op_se1
capture matrix drop eop_se1
matrix rename eop_se eop_se1

local niv50lst : colfullnames lp_b
local estsols : rowfullnames ols_b
local estslp  : rowfullnames lp_b
local estsop : rowfullnames op_b
local estseop : rowfullnames eop_b

foreach esttype in ols lp op eop {
  local bsttype = "`esttype'_se2"
  matrix `bsttype' = J(rowsof(`esttype'_se1),colsof(`esttype'_se1),-999)
  matrix colnames `bsttype' = `niv50lst'
  matrix rownames `bsttype' = `ests`esttype''
  }

tokenize "`niv50lst'"
local nivimax : word count `niv50lst'

forvalues nivi = 1/`nivimax' { 
    local niv = substr("``nivi''",4,2)
    local run = 1
    use "tfpest/estimate/bstrp/niv`niv'-`ext'`fdfl'-`outtype'-run`run'", clear
    local exit = 0
    while ~`exit' {
        local run = `run' + 1
        capture confirm file "tfpest/estimate/bstrp/niv`niv'-`ext'`fdfl'-`outtype'-run`run'.dta"
        if _rc==601 {local exit=1}
        else        {append using "tfpest/estimate/bstrp/niv`niv'-`ext'`fdfl'-`outtype'-run`run'"}
    }
    order olslbl olslwh olsm olsk lplbl lplwh lpm lpk oplbl oplwh opm opk opinv eoplbl eoplwh eopm eopk eopmpen
    foreach esttype in ols lp op eop {
        local bsttype = "`esttype'_se2"
        local rowi 0
        foreach est in `esttype'lbl `esttype'lwh `esttype'm `esttype'k {
          local rowi = `rowi' + 1
          qui bstat `est'
          matrix `bsttype'[`rowi',`nivi'] = r(se)
         }
      if "`esttype'"=="op" {
        local est = "opinv"
        local rowi = `rowi' + 1
        qui bstat `est'
        matrix `bsttype'[`rowi',`nivi'] = r(se)
      }
      if "`esttype'"=="eop" {
        local est = "eopmpen"
        local rowi = `rowi' + 1
        qui bstat `est'
        matrix `bsttype'[`rowi',`nivi'] = r(se)
      }
    }
  }

local niv50lst : colfullnames lp_b
local nivimax : word count `niv50lst'
local estsols : rowfullnames ols_b
local estslp  : rowfullnames lp_b
local estsop : rowfullnames op_b
local estseop : rowfullnames eop_b
tokenize "`niv50lst'"

foreach esttype in ols lp { 
  foreach type in b se1 se2 {
    matrix `esttype'_`type' = `esttype'_`type' \ J(1,`nivimax',-999)
    }
  }

foreach esttype in ols lp op eop { 
  foreach type in b se1 se2 {
  local rowmax = rowsof(`esttype'_b)
  local rowse = rowsof(`esttype'_e)
  local rowsr = rowsof(`esttype'_r)
    matrix list`esttype'_`type' = `esttype'_`type'[1..`rowmax',1]
    if "`type'"=="b" {
        matrix list`esttype'_`type' = list`esttype'_`type' \ `esttype'_e[1..`rowse',1] \ `esttype'_r[1..`rowsr',1]
        }
    else {
        matrix list`esttype'_`type' = list`esttype'_`type' \ J(`rowse',1,-999) \ J(`rowsr',1,-999)
        }
    forvalues nivi = 2/`nivimax' { 
        matrix list`esttype'_`type' = list`esttype'_`type' \ `esttype'_`type'[1..`rowmax',`nivi']
        if "`type'"=="b" {
            matrix list`esttype'_`type' = list`esttype'_`type' \ `esttype'_e[1..`rowse',`nivi'] \ `esttype'_r[1..`rowsr',`nivi']
            }
        else {
            matrix list`esttype'_`type' = list`esttype'_`type' \ J(`rowse',1,-999) \ J(`rowsr',1,-999)
            }
        }
    local rowmax = `rowmax' + `rowse' + `rowsr'
    local stp = 0
    forvalues nivi = 1/`nivimax' { 
        forvalues row = 1/`rowmax' {
            local rowid = `row' + `stp'
            matname list`esttype'_`type' "``nivi'':", rows(`rowid') explicit
            }
        local stp = `stp' + `rowmax'
        }
    matrix colnames list`esttype'_`type' = `esttype'_`type'
    }
  }

matrix eoplpols_tbl = listeop_b , listeop_se2 , listop_b , listop_se2 , listlp_b , listlp_se2 , listols_b , listols_se2

preserve
drop _all
est2tex eoplpols, ready replace p(c:/texdocs/tfpest/stata-origs) fancy extracols(2 4 6) thousep
restore
