version 7.0
set matsize 180
set more off

/* Creates : 
    matrix  pfct013_b    /* Point estimates from 0-draw in bootstrap, but not from again- */
    matrix  pfct013_se1  /* Analytic standard deviations, from general routine */
    matrix  pfct013_se2  /* Bootstrap standard deviations, based on 200 bootstraps */
    matrix  pfct013_e    /* Number of observations behind regressions */
*/



/* Choose Settings */
/*-----------------*/

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext "gen"}

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {local outtype "valadd"}
if $out==2 {local outtype "output"}

global trd 0
/* Choice 3: Klette & Griliches 96 correction */
/* Choice 2: year dummies ON, trend variables OFF */
/* Choice 1: trend variables ON, time dummies OFF  */
/* Choice 0: trend variables and year dummies OFF */
if $trd==3 {local trdtype "kletgri"}
if $trd==2 {local trdtype "dyears"}
if $trd==1 {local trdtype "trend"}
if $trd==0 {local trdtype "notrend"}

global fe 2
/* Choice 2: fixed effects in OP estimation ON, AND KletGri96 inspired correction */
/* Choice 1: fixed effects in OP estimation ON  */
/* Choice 0: fixed effects in OP estimation OFF */
if $fe==2 & "`esttype'"~="op" {global fe 1}
if $fe~=0 {local fetype "fe"}
else      {local fetype "nofe"}
if $fe==2 {local feout="fecorr"}
else      {local feout="`fetype'"}

global polynl 3
/* Choice 2: Polynomial of 2nd order is used in Step 3 */
/* Choice 3: Polynomial of 3rd order is used in Step 3 */
/* Choice 4: Polynomial of 4th order is used in Step 3 */
/* Choice 5: Polynomial of 5th order is used in Step 3 */
/* Choice 6: Polynomial of 6th order is used in Step 3 */
local polynl=$polynl

local polykap 2
/* Choice 2: Polynomial of 2nd order is used in Step 3 */
/* Choice 3: Polynomial of 3rd order is used in Step 3 */
/* Choice 4: Polynomial of 4th order is used in Step 3 */
/* Choice 5: Polynomial of 5th order is used in Step 3 */
/* Choice 6: Polynomial of 6th order is used in Step 3 */
local polynl=$polynl

global xeff 1
/* Choice 1: Approximate for X-efficiency choice by managers */
/* Choice 0: Approximate for X-efficiency choice by managers */
if $xeff {local xeff="x"}
if "$posinv" == "-nomkt" {local xeff=""}

/* Load estimate matrices and bootstrap data */

foreach estmat in "1bet" "3bet" "1sdv" "3sdv" {
    if _N >0 {drop _all}
    matload stp`estmat', path("tfpest\estimate\estmat\mat$posinv-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'\")
}

matrix stp1se1 = stp1sdv
matrix stp3se1 = stp3sdv
matrix drop stp1sdv
matrix drop stp3sdv
matrix stp1b = stp1bet
matrix stp3b = stp3bet
matrix drop stp1bet
matrix drop stp3bet

foreach type in b se1 {
    if "`type'" == "b" {matrix _lnlabfsm = stp1`type'[rownumb(stp1`type',"lnlabfbl"),1..colsof(stp1`type')] + stp1`type'[rownumb(stp1`type',"lnlabfwh"),1..colsof(stp1`type')]}
    else {matrix _lnlabfsm = J(1,colsof(stp1`type'),-999)}
    matrix rownames _lnlabfsm = lnlabfsm
    if "`type'" == "b" {matrix _bcapsm = stp3`type'[rownumb(stp3`type',"bk"),1..colsof(stp1`type')] + stp3`type'[rownumb(stp3`type',"bq"),1..colsof(stp1`type')]}
    else {matrix _bcapsm = J(1,colsof(stp1`type'),-999)}
    matrix rownames _bcapsm = bcapsm
    matrix pfct${trd}${fe}${polynl}_`type' = stp1`type'[rownumb(stp1`type',"lnlabfbl"),1..colsof(stp1`type')] \ stp1`type'[rownumb(stp1`type',"lnlabfwh"),1..colsof(stp1`type')] \ stp1`type'[rownumb(stp1`type',"mu"),1..colsof(stp1`type')] \ stp1`type'[rownumb(stp1`type',"lnintmed"),1..colsof(stp1`type')] \ _lnlabfsm
    matrix pfct${trd}${fe}${polynl}_`type' = pfct${trd}${fe}${polynl}_`type' \ stp3`type'[rownumb(stp3`type',"bkappa"),1..colsof(stp3`type')] \ stp3`type'[rownumb(stp3`type',"bk"),1..colsof(stp3`type')] \ stp3`type'[rownumb(stp3`type',"bq"),1..colsof(stp3`type')]
    matrix pfct${trd}${fe}${polynl}_`type' = pfct${trd}${fe}${polynl}_`type' \ _bcapsm
}
matrix drop _bcapsm
matrix drop _lnlabfsm

local niv50lst : colfullnames pfct${trd}${fe}${polynl}_b
local ests : rowfullnames pfct${trd}${fe}${polynl}_b

local chk 0
local bcftype = "pfct${trd}${fe}${polynl}_b"
local bsttype = "pfct${trd}${fe}${polynl}_se2"
matrix `bsttype' = J(rowsof(pfct${trd}${fe}${polynl}_b),colsof(pfct${trd}${fe}${polynl}_b),-999)
matrix colnames `bsttype' = `niv50lst'
matrix rownames `bsttype' = `ests'
local nivimax = colsof(pfct${trd}${fe}${polynl}_b)
tokenize "`niv50lst'"
forvalues nivi = 1/`nivimax' { 
    local niv = substr("``nivi''",4,2)
    local run = 1
    use "tfpest\estimate\bstrp\niv`niv'$posinv-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-run`run'", clear
    local exit = 0
    while ~`exit' {
        local run = `run' + 1
        capture confirm file "tfpest\estimate\bstrp\niv`niv'$posinv-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-run`run'.dta"
        if _rc==601 {local exit=1}
        else        {append using "tfpest\estimate\bstrp\niv`niv'$posinv-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-run`run'"}
    }
    keep kappa lnk lnq mu lnintm lnlabfwh lnlabfbl
    rename kappa bkappa
    rename lnk bk
    rename lnq bq
    gen lnlabfsm = lnlabfbl + lnlabfwh
    gen bcapsm = bk + bq
    local lnlabfsm = 0
    foreach est in lnlabfbl lnlabfwh {
        qui bstat `est'
        local lnlabfsm = `lnlabfsm' + r(stat)
    }
    local bcapsm = 0
    foreach est in bk bq {
        qui bstat `est'
        local bcapsm = `bcapsm' + r(stat)
    }
    local rowi 0
    foreach est in lnlabfbl lnlabfwh mu lnintm lnlabfsm bkappa bk bq bcapsm {
        local rowi = `rowi' + 1
        if "`est'"~="lnlabfsm" & "`est'"~="bcapsm" {qui bstat `est'}
        if "`est'"=="lnlabfsm" {qui bstat `est', stat(`lnlabfsm')}
        if "`est'"=="bcapsm"   {qui bstat `est', stat(`bcapsm')}
        if int(el(`bcftype',`rowi',`nivi')*100)~=int(`r(stat)'*100) {
          * disp el(`bcftype',`rowi',`nivi')
          * disp `r(stat)'
          local chk = `chk' + 1
          }
        matrix `bcftype'[`rowi',`nivi'] = r(stat)
        matrix `bsttype'[`rowi',`nivi'] = r(se)
    }
    local tot `rowi'*`nivi'
}
set more on
disp in red "Differing bootstrap point estimates from general-routine point estimates (at second digit) in " in yellow `chk' in red "/" in yellow `tot' in red " cases."
more
set more off

use "tfpest\estimate\coeff$posinv-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", clear
sort niv50
by niv50: keep if _n==1
drop firm-lnintmed phi* phat* indsurvv*
gen str2 _rowname = string(niv50)
replace _rowname = "0" + _rowname if niv50<10
replace _rowname = "niv" + _rowname
order _rowname

local niv50lst : colfullnames pfct${trd}${fe}${polynl}_b
matrix pfct${trd}${fe}${polynl}_e = J(1,colsof(pfct${trd}${fe}${polynl}_b),-999)
matrix colnames pfct${trd}${fe}${polynl}_e = `niv50lst'
matrix rownames pfct${trd}${fe}${polynl}_e = e(N)_op
local maxcol = colsof(pfct${trd}${fe}${polynl}_b)
forvalues coli = 1/`maxcol' {
    matrix pfct${trd}${fe}${polynl}_e[1,`coli'] = obsnum[`coli']
    matrix pfct${trd}${fe}${polynl}_se1[5,`coli'] = sqrt( bsdvbl[`coli'] + bsdvwh[`coli'] + 2*bcovlb[`coli'] )
    matrix pfct${trd}${fe}${polynl}_se1[9,`coli'] = sqrt( bsdvk[`coli'] + bsdvq[`coli'] + 2*bcovk[`coli'] )
}

local see_right : rowfullnames pfct${trd}${fe}${polynl}_b
keep _rowname ols* wi* 
local type = "ols"
preserve
foreach type in ols wi {
    restore, preserve
    keep `type'* _rowname
    gen `type'betlbfsm = `type'betbl + `type'betwh
    gen `type'betcapsm = `type'betk + `type'betq
    gen `type'sdvlbfsm = sqrt( `type'sdvbl + `type'sdvwh + 2*`type'covlb )
    gen `type'sdvcapsm = sqrt( `type'sdvk + `type'sdvq + 2*`type'covk )   
    order _rowname `type'betbl `type'betwh `type'mu `type'betintm `type'betlbfsm `type'kappa `type'betk `type'betq `type'betcapsm `type'sdvbl `type'sdvwh `type'sdvmu `type'sdvintm `type'sdvlbfsm `type'sdvkap `type'sdvk `type'sdvq `type'sdvcapsm
    save mat`type', replace
    drop _all
    capture matrix drop mat`type'
    matload mat`type'
    erase mat`type'.dta
    matrix mat`type' = mat`type' '
    matrix pfct${trd}${fe}${polynl}_e = pfct${trd}${fe}${polynl}_e \ mat`type'[rownumb(mat`type',"`type'num"),1..colsof(mat`type')]
    local rownum = rowsof(pfct${trd}${fe}${polynl}_e)
    matname pfct${trd}${fe}${polynl}_e "e(N)_`type'" , rows(`rownum') explicit
    matrix mat`type'_b = mat`type'[1..9,1..colsof(mat`type')]
    matrix mat`type'_se = mat`type'[10..18,1..colsof(mat`type')]
    local see_b : rowfullnames mat`type'_b
    local see_se : rowfullnames mat`type'_se
    disp in blue "Check whether order appropriate:"
    disp "`see_b'"
    disp "`see_se'"
    disp "`see_right'"
    matrix rownames mat`type'_b = `type'labfbl `type'labfwh `type'mu `type'intmed `type'labfsm `type'kappa `type'lnk `type'lnq `type'capsm
    matrix rownames mat`type'_se = `type'labfbl `type'labfwh `type'mu `type'intmed `type'labfsm `type'kappa `type'lnk `type'lnq `type'capsm
    matrix pfct${trd}${fe}${polynl}_b = pfct${trd}${fe}${polynl}_b \ mat`type'_b
    matrix pfct${trd}${fe}${polynl}_se1 = pfct${trd}${fe}${polynl}_se1 \ mat`type'_se
    matrix drop mat`type'
    matrix drop mat`type'_b
    matrix drop mat`type'_se  
}
restore 

local namtrs : rowfullnames pfct${trd}${fe}${polynl}_se1
tokenize "`namtrs'"
matrix pfct${trd}${fe}${polynl}_se2 = pfct${trd}${fe}${polynl}_se2 \ J(18,colsof(pfct${trd}${fe}${polynl}_se2),-999)
local rowmax = rowsof(pfct${trd}${fe}${polynl}_se2)
forvalues rowi = 1/`rowmax' {
    matname pfct${trd}${fe}${polynl}_se2 ``rowi'', rows(`rowi') explicit
}

foreach type in b se1 se2 e {
    /* matrix list pfct${trd}${fe}${polynl}_`type' */
    drop _all
    capture mkdir "tfpest/estimate/estmat/pfct$posinv"
    matsave pfct${trd}${fe}${polynl}_`type', path(tfpest/estimate/estmat/pfct$posinv) replace
}


/* Create TeX files */

if "$posinv" == "" {

/* Production functions for appendix */

foreach type in b se1 se2 {
    drop _all
    matrix pfctall_`type' = pfct${trd}${fe}${polynl}_`type' '
    matsave pfctall_`type', replace
    keep _rowname bkappa bk bq mu lnintm lnlabfwh lnlabfbl wikappa wilnk wimu wiintmed
    order _rowname bkappa bk bq mu lnintm lnlabfwh lnlabfbl wikappa wilnk wimu wiintmed
    save pfctall_`type', replace
    drop _all
    matrix drop pfctall_`type'
    matload pfctall_`type'
    matrix pfctall_`type' = pfctall_`type' '
}
matrix pfctall_e = pfct${trd}${fe}${polynl}_e
matrix rownames pfctall_e = Nop Nols Nwi

matrix _dummy = J(3,colsof(pfctall_e),-999)
local rownam : rowfullnames pfctall_e
local colnam : colfullnames pfctall_e
matrix rownames _dummy = `rownam'
matrix colnames _dummy = `colnam'
foreach type in se1 se2 {
     matrix pfctall_`type' = pfctall_`type' \ _dummy
}
matrix pfctall_b = pfctall_b \ pfctall_e
matrix drop _dummy

foreach type in b se1 se2 {
    matrix pfctall_`type' = pfctall_`type' '
    drop _all
    matsave pfctall_`type', replace
    keep _rowname Nop Nwi bkappa bk bq mu lnint lnlab* wikapp wilnk wimu wiint
    order _rowname Nop Nwi bkappa bk bq mu lnint lnlab* wikapp wilnk wimu wiint
    save pfctall_`type', replace
    matrix drop pfctall_`type'
    drop _all
    matload pfctall_`type'
    matrix pfctall_`type' = pfctall_`type' '
    /* matname pfctall_`type' Nop Nwi kap k q mu intm wh bl wikap wik wimu wiintm, columns(1..13) explicit */
}

/* Determine which of the standard errors to use */
matrix pfctall_se = pfctall_se2[1..9,1..colsof(pfctall_se2)] \ pfctall_se2[10..13,1..colsof(pfctall_se2)]

est2tex pfctall, hori replace p(c:\texdocs\tfpest\stata-origs) fancy extracols(9) cut mark(it)


/* Create reduced table for text */
matrix pfcttxt_b =  pfctall_b[1,1..`nivimax']  \ pfctall_b[3..9,1..`nivimax']
matrix pfcttxt_se = pfctall_se[1,1..`nivimax'] \ pfctall_se[3..9,1..`nivimax']

drop _all
est2tex pfcttxt, hori replace p(c:\texdocs\tfpest\stata-origs) fancy extracols(1 4 6) cut mark(it)


/* Remove temporary files */

foreach type in b se1 se2 {
  erase pfctall_`type'.dta
}

}
