version 8
set matsize 180
set logtype text
capture log close
set more off


/* Choose Settings */
/*-----------------*/

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {
    local ext "ipa"
    }
if `choice'==4 {
    local ext "di"
    }
if `choice'==9 {
    local ext "gen"
    }

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { 
    local fdfl="" 
    }

global out 2
/* Choice 2: "output" */
if $out==2 {
    local outtype "output"
    }


/* Load variable names and save for est2tex */

insheet using "tfpest/summ/regressor-list.tex", delimiter("&") clear
rename v1 _rowname
rename v2 _rowlbl
replace _rowname = trim(_rowname)
replace _rowlbl = trim(_rowlbl)
drop if _rowname=="" & _rowlbl==""
sort _rowname
compress
save "c:/texdocs/tfpest/stata-origs/attri_rowlbl", replace
save "c:/texdocs/tfpest/stata-origs/summ_rowlbl", replace
save "c:/texdocs/tfpest/stata-origs/attritop5_rowlbl", replace
save "c:/texdocs/tfpest/stata-origs/summtop5_rowlbl", replace


capture log close
log using "tfpest/summ/summ.log", replace

use "tfpest/use-tfp-`ext'`fdfl'-`outtype'-notrend", clear
keep firm year niv50 lnvaladd lnoutput kappa* lnapk* lnapq* lnlabfbl lnlabfwh mu lnintmed nt* reffpen realexch tariff kletgril inflrate


/* Import policy and demand variables */
sort firm year
merge firm year using "tfpest/seclvl-`ext'`fdfl'", update
drop _merge
sort firm year
by firm year: keep if _n==1
/* Import competitor variables */
sort firm year
merge firm year using "tfpest/varsothrs-`ext'`fdfl'", update
tab _m
drop _merge
sort firm year
by firm year: keep if _n==1

rename kletgril lnaggdem
replace lnaggdem = ln(exp(lnaggdem)/1000)
gen lnapktot = log(exp(lnapk1) + exp(lnapq1))
gen lnlbftot = log(exp(lnlabfbl) + exp(lnlabfwh))
gen nttotinv = ntkinv + ntqinv
label var lnapktot "Log Total Capital Stock - End Y"
label var lnlbftot "Log Total Labor Force"
label var nttotinv "Net Total Investment"
gen ntinv_mpen = nttotinv * L.reffpen
label var ntinv_mpen "Interact Net Tot. Inv. * Eff. Penetr."

tsset firm year


/* All sectors: Attrition table */

preserve

* Labor force composition
egen _secgrp = group(niv50)
qui summ _secgrp
local nivcnt = `r(max)'
sort year
qui summ year
local yrmin = `r(min)'
local yrmax = `r(max)'
mat labfwhsh_tbl = J(`yrmax'-`yrmin'+1,`nivcnt'+1,-999)
gen double _shwh = exp(lnlabfwh)/(exp(lnlabfbl) + exp(lnlabfwh))
gen double _totlf = (exp(lnlabfbl) + exp(lnlabfwh))
matname labfwhsh_tbl niv50:allsec, columns(1) explicit
forvalues yr = `yrmin'/`yrmax' {
  local rowi = `yr'-`yrmin'+1
  matname labfwhsh_tbl 19`yr', rows(`rowi') explicit
  qui summ _shwh if year==`yr' [w=_totlf], meanonly
  if "`r(mean)'"~=""  mat labfwhsh_tbl[`rowi',1] = `r(mean)'
  }
local colj = 1
forvalues secj = 1/`nivcnt' {
  local colj = `colj'+1
  qui summ niv50 if _secgrp==`secj', meanonly
  matname labfwhsh_tbl niv50:`r(mean)', columns(`colj') explicit
  forvalues yr = `yrmin'/`yrmax' {
    local rowi = `yr'-`yrmin'+1
    qui summ _shwh if year==`yr' & _secgrp==`secj' [w=_totlf], meanonly
    if "`r(mean)'"~=""  mat labfwhsh_tbl[`rowi',`colj'] = `r(mean)'
    }
  }
drop _*

/* XXX
replace year = year+1900
keep firm year lnoutput
drop if lnoutput==.
drop if year==1991 | year==.
tab year
foreach yr in 90 89 88 87 86 {
    replace year = 19`yr' + 1 if year==19`yr'
    }
fillin firm year

local endyr  = 98
forvalues strtyr = 87/97 {
    if `strtyr' <= 91 { 
        local pltyr = `strtyr' - 1 
        } 
    else { 
        local pltyr = `strtyr'
        } 
    sort firm
    qui by firm: egen _cnt = sum(_fillin) if year>=19`strtyr' & year<=19`endyr'
    di
    disp in green "Year " in yellow "19`pltyr'"
    qui count if year==19`strtyr' & ~_fillin
    local cnt`pltyr' = `r(N)'
    disp in green "Firms in 19`pltyr': " in yellow "`cnt`pltyr''"
    qui count if year==19`strtyr' & _cnt==0 & ~_fillin
    local cnt`pltyr'sv = `r(N)'
    disp in green "Present from 19`pltyr' through 1998: " in yellow "`cnt`pltyr'sv'"
    drop _cnt
    }
foreach yr in 86 87 88 89 90 {
    replace year = 19`yr' if year==19`yr' + 1
    }

matrix attri_tbl = J(13,2,-999)
local i 0
forvalues strtyr = 87/97 {
    local i = `i' + 1
    if `strtyr' <= 91 { 
        local pltyr = `strtyr' - 1 
        } 
    else { 
        local pltyr = `strtyr'
        } 
    matrix attri_tbl[`i',1] = `cnt`pltyr''
    matrix attri_tbl[`i',2] = `cnt`pltyr'sv'
    matname attri_tbl 19`pltyr', rows(`i') explicit
    }
drop if _fillin
drop _*
count 
matrix attri_tbl[13,1] = `r(N)'
sort firm
count if firm~=firm[_n-1]
matrix attri_tbl[13,2] = `r(N)'
matrix colnames attri_tbl = obs survobs
matname attri_tbl "_", rows(13) explicit
matname attri_tbl "obs_panels", rows(13) explicit

drop _all
est2tex attri, ready replace dropall preserve p(c:/texdocs/tfpest/stata-origs) fancy thousep
drop _all
est2tex labfwhsh, ready replace dropall preserve p(c:/texdocs/tfpest/stata-origs) fancy thousep


/* All sectors: Summary Statistics */

restore, preserve

rename oth_lnapk1 lnoth_apk1

local varcnt 0
foreach var in lnoutput lnvaladd lnintmed lnapktot lnapk1 lnapq1 nttotinv ntkinv ntqinv lnaggdem lnoth_apk1 oth_lpprox ntinv_mpen {
    local varcnt = `varcnt' + 1
    if substr("`var'",1,2)=="ln" { 
        local var = subinstr("`var'","ln","",1)
        gen `var' = exp(ln`var')
        }
    qui replace `var' = `var'/1000000
    qui summ `var', detail
    local varnm`varcnt' = "`var'"
    local r`varcnt'c1 = `r(mean)'
    local r`varcnt'c2 = `r(sd)'
    local r`varcnt'c3 = `r(p50)'
    local r`varcnt'c4 = `r(N)'
    }
foreach var in lnlbftot lnlabfbl lnlabfwh mu kappa1 reffpen herfsale tariff {
    local varcnt = `varcnt' + 1
    if substr("`var'",1,2)=="ln" { 
        local var = subinstr("`var'","ln","",1)
        gen `var' = exp(ln`var')
        }
    qui summ `var', detail
    local varnm`varcnt' = "`var'"
    local r`varcnt'c1 = `r(mean)'
    local r`varcnt'c2 = `r(sd)'
    local r`varcnt'c3 = `r(p50)'
    local r`varcnt'c4 = `r(N)'
    }
matrix summ_tbl = J(`varcnt',4,-999)
local i = 1
forvalues i = 1/`varcnt' {
    matrix summ_tbl[`i',1] = `r`i'c1'
    matrix summ_tbl[`i',2] = `r`i'c2'
    matrix summ_tbl[`i',3] = `r`i'c3'
    matrix summ_tbl[`i',4] = `r`i'c4'
    matrix colnames summ_tbl = mean sd median obs
    matname summ_tbl `varnm`i'', rows(`i') explicit
    }
matrix zeroinv_tbl = J(3,2,-999)
matrix rownames zeroinv_tbl = nttotinv ntkinv ntqinv
matrix colnames zeroinv_tbl = obs totobs
local i 0
foreach var in nttotinv ntkinv ntqinv {
  local i = `i' + 1
  count if `var'==0
  mat zeroinv_tbl[`i',1] = `r(N)'
  count if `var'~=.
  mat zeroinv_tbl[`i',2] = `r(N)'
  }

drop _all
est2tex summ, ready replace dropall preserve p(c:/texdocs/tfpest/stata-origs) fancy thousep
drop _all
est2tex zeroinv, ready replace dropall preserve p(c:/texdocs/tfpest/stata-origs) fancy thousep


/* TOP 5: Attrition table */

XXX */

restore, preserve

keep if niv50==31 | niv50==22 | niv50==14 | niv50==26 | niv50==8

* Labor force composition
egen _secgrp = group(niv50)
qui summ _secgrp
local nivcnt = `r(max)'
sort year
qui summ year
local yrmin = `r(min)'
local yrmax = `r(max)'
mat labfwhshtop5_tbl = J(`yrmax'-`yrmin'+1,`nivcnt'+1,-999)
gen double _shwh = exp(lnlabfwh)/(exp(lnlabfbl) + exp(lnlabfwh))
gen double _totlf = (exp(lnlabfbl) + exp(lnlabfwh))
matname labfwhshtop5_tbl niv50:allbut31, columns(1) explicit
forvalues yr = `yrmin'/`yrmax' {
  local rowi = `yr'-`yrmin'+1
  matname labfwhshtop5_tbl 19`yr', rows(`rowi') explicit
  qui summ _shwh if year==`yr' & niv50~=31 [w=_totlf], meanonly
  if "`r(mean)'"~=""  mat labfwhshtop5_tbl[`rowi',1] = `r(mean)'
  }
local colj = 1
forvalues secj = 1/`nivcnt' {
  local colj = `colj'+1
  qui summ niv50 if _secgrp==`secj', meanonly
  matname labfwhshtop5_tbl niv50:`r(mean)', columns(`colj') explicit
  forvalues yr = `yrmin'/`yrmax' {
    local rowi = `yr'-`yrmin'+1
    qui summ _shwh if year==`yr' & _secgrp==`secj' [w=_totlf], meanonly
    if "`r(mean)'"~=""  mat labfwhshtop5_tbl[`rowi',`colj'] = `r(mean)'
    }
  }
drop _*

replace year = year+1900
keep firm year lnoutput
drop if lnoutput==.
drop if year==1991 | year==.
tab year
foreach yr in 90 89 88 87 86 {
    replace year = 19`yr' + 1 if year==19`yr'
    }
fillin firm year

local endyr  = 98
forvalues strtyr = 87/97 {
    if `strtyr' <= 91 { 
        local pltyr = `strtyr' - 1 
        } 
    else { 
        local pltyr = `strtyr'
        } 
    sort firm
    qui by firm: egen _cnt = sum(_fillin) if year>=19`strtyr' & year<=19`endyr'
    di
    disp in green "Year " in yellow "19`pltyr'"
    qui count if year==19`strtyr' & ~_fillin
    local cnt`pltyr' = `r(N)'
    disp in green "Firms in 19`pltyr': " in yellow "`cnt`pltyr''"
    qui count if year==19`strtyr' & _cnt==0 & ~_fillin
    local cnt`pltyr'sv = `r(N)'
    disp in green "Present from 19`pltyr' through 1998: " in yellow "`cnt`pltyr'sv'"
    drop _cnt
    }
foreach yr in 86 87 88 89 90 {
    replace year = 19`yr' if year==19`yr' + 1
    }

matrix attritop5_tbl = J(13,2,-999)
local i 0
forvalues strtyr = 87/97 {
    local i = `i' + 1
    if `strtyr' <= 91 { 
        local pltyr = `strtyr' - 1 
        } 
    else { 
        local pltyr = `strtyr'
        } 
    matrix attritop5_tbl[`i',1] = `cnt`pltyr''
    matrix attritop5_tbl[`i',2] = `cnt`pltyr'sv'
    matname attritop5_tbl 19`pltyr', rows(`i') explicit
    }
drop if _fillin
drop _*
count 
matrix attritop5_tbl[13,1] = `r(N)'
sort firm
count if firm~=firm[_n-1]
matrix attritop5_tbl[13,2] = `r(N)'
matrix colnames attritop5_tbl = obs survobs
matname attritop5_tbl "_", rows(13) explicit
matname attritop5_tbl "obs_panels", rows(13) explicit

drop _all
est2tex attritop5, ready replace dropall preserve p(c:/texdocs/tfpest/stata-origs) fancy thousep
drop _all
est2tex labfwhshtop5, ready replace dropall preserve p(c:/texdocs/tfpest/stata-origs) fancy thousep


/* TOP 5 sectors: Summary Statistics */

restore, preserve

keep if niv50==31 | niv50==22 | niv50==14 | niv50==26 | niv50==8

rename oth_lnapk1 lnoth_apk1

local varcnt 0
foreach var in lnoutput lnvaladd lnintmed lnapktot lnapk1 lnapq1 nttotinv ntkinv ntqinv lnaggdem lnoth_apk1 oth_lpprox ntinv_mpen {
    local varcnt = `varcnt' + 1
    if substr("`var'",1,2)=="ln" { 
        local var = subinstr("`var'","ln","",1)
        gen `var' = exp(ln`var')
        }
    qui replace `var' = `var'/1000000
    qui summ `var', detail
    local varnm`varcnt' = "`var'"
    local r`varcnt'c1 = `r(mean)'
    local r`varcnt'c2 = `r(sd)'
    local r`varcnt'c3 = `r(p50)'
    local r`varcnt'c4 = `r(N)'
    }
foreach var in lnlbftot lnlabfbl lnlabfwh mu kappa1 reffpen herfsale tariff {
    local varcnt = `varcnt' + 1
    if substr("`var'",1,2)=="ln" { 
        local var = subinstr("`var'","ln","",1)
        gen `var' = exp(ln`var')
        }
    qui summ `var', detail
    local varnm`varcnt' = "`var'"
    local r`varcnt'c1 = `r(mean)'
    local r`varcnt'c2 = `r(sd)'
    local r`varcnt'c3 = `r(p50)'
    local r`varcnt'c4 = `r(N)'
    }
matrix summtop5_tbl = J(`varcnt',4,-999)
local i = 1
forvalues i = 1/`varcnt' {
    matrix summtop5_tbl[`i',1] = `r`i'c1'
    matrix summtop5_tbl[`i',2] = `r`i'c2'
    matrix summtop5_tbl[`i',3] = `r`i'c3'
    matrix summtop5_tbl[`i',4] = `r`i'c4'
    matrix colnames summtop5_tbl = mean sd median obs
    matname summtop5_tbl `varnm`i'', rows(`i') explicit
    }
matrix zeroinvtop5_tbl = J(3,2,-999)
matrix rownames zeroinvtop5_tbl = nttotinv ntkinv ntqinv
matrix colnames zeroinvtop5_tbl = obs totobs
local i 0
foreach var in nttotinv ntkinv ntqinv {
  local i = `i' + 1
  count if `var'==0
  mat zeroinvtop5_tbl[`i',1] = `r(N)'
  count if `var'~=.
  mat zeroinvtop5_tbl[`i',2] = `r(N)'
  }

drop _all
est2tex summtop5, ready replace dropall preserve p(c:/texdocs/tfpest/stata-origs) fancy thousep
drop _all
est2tex zeroinvtop5, ready replace dropall preserve p(c:/texdocs/tfpest/stata-origs) fancy thousep

restore
