version 7.0

/* Choose Settings */
/*-----------------*/

local rebase=1
/* Choice 1: Rebase logtfp by sector (after sector aggregation) so that 1986==1 before aggregation */
/* Choice 0: Only rebase at aggregation */

foreach esttype in $esttype {
/* Choice "ols": OLS         */
/*        "fe" : Within Eff. */
/*        "op" : Olley-Pakes */
/*        "eop": Expectations-extended Olley-Pakes */

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext "gen"}

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {local outtype "valadd"}
if $out==2 {local outtype "output"}

global trd 0
/* Choice 3: Klette & Griliches 96 correction */
/* Choice 2: year dummies ON, trend variables OFF */
/* Choice 1: trend variables ON, time dummies OFF  */
/* Choice 0: trend variables and year dummies OFF */
if $trd==3 {local trdtype "kletgri"}
if $trd==2 {local trdtype "dyears"}
if $trd==1 {local trdtype "trend"}
if $trd==0 {local trdtype "notrend"}

global fe 2
/* Choice 2: fixed effects in OP estimation ON, AND KletGri96 inspired correction */
/* Choice 1: fixed effects in OP estimation ON  */
/* Choice 0: fixed effects in OP estimation OFF */
if $fe==2 & "`esttype'"~="op" {global fe 1}
if $fe~=0 {local fetype "fe"}
else      {local fetype "nofe"}
if $fe==2 {local feout="fecorr"}
else      {local feout="`fetype'"}

global polynl 3
/* Choice 2: Polynomial of 2nd order is used in Step 3 */
/* Choice 3: Polynomial of 3rd order is used in Step 3 */
/* Choice 4: Polynomial of 4th order is used in Step 3 */
/* Choice 5: Polynomial of 5th order is used in Step 3 */
/* Choice 6: Polynomial of 6th order is used in Step 3 */
local polynl=$polynl

global xeff 1
/* Choice 1: Approximate for X-efficiency choice by managers */
/* Choice 0: Approximate for X-efficiency choice by managers */
if $xeff {local xeff="x"}


/* Load aggregate data */
/* aggtype==1: All industry, aggtype==2: 13 selected sectors */
/* region==0: Sao Paulo, region==1: North and NorthEast, region==3: South and SouthEast, region==9: total */
/* sample==1: all firms (entrants, exiting firms, stayers), sample==2: stayers only */


/* Figure 3.4 in WB draft */

use "tfpest/aggtfp/prodlevel`rebase'-annual-compagg-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", clear
replace year=year+1900
keep aggtype year region nmagglntfp1 lntfp*
reshape wide nmagg lntfp*, i(year region) j(aggtype)
drop lntfppim2 lntfpfiesp2
foreach var in lntfppim lntfpfiesp { rename `var'1 `var' }
label var nmagglntfp11 "Log TFP All Sectors"
label var nmagglntfp12 "Log TFP Industry 14"
label var lntfppim     "Log TFP Gomes (2001)"
/* (all including entry and exit) */
graph nmagglntfp11 nmagglntfp12 lntfppim year if region==9, connect(llll) saving("c:/texdocs/tfpest/fig/graphs/tfplevel-`esttype'-`ext'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2", replace) xtick(1986,1987,1988,1989,1990,1991,1992,1993,1994,1995,1996,1997,1998) xlabel(1986,1989,1992,1995,1998) ytick(.95 .975 to 1.05) ylab(.95,1,1.05) rlab(.85 .9 to 1.25) yline(.95,1,1.05,1.15)
translate "c:/texdocs/tfpest/fig/graphs/tfplevel-`esttype'-`ext'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2.gph" "c:/texdocs/tfpest/fig/graphs/tfplevel-`esttype'-`ext'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2.eps", translator(gph2eps) replace
erase "c:/texdocs/tfpest/fig/graphs/tfplevel-`esttype'-`ext'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2.gph"
more


/* Figure 3.5 in WB draft */

use "tfpest/aggtfp/prodlevel`rebase'-annual-agg-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", clear
replace year=year+1900
foreach i in 1 2 { replace agglntfp`i'=. if agglntfp`i'==0 }
keep aggtype year region agglntfp*
label var agglntfp1 "Log TFP Stayers, Entry and Exit"
label var agglntfp2 "Log TFP Stayers only"
graph agglntfp1 agglntfp2 year if region==9 & aggtype==1, connect(llll) saving("c:/texdocs/tfpest/fig/graphs/tfplevel-entrext-`esttype'-`ext'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2", replace) xtick(1986,1987,1988,1989,1990,1991,1992,1993,1994,1995,1996,1997,1998) xlabel(1986,1989,1992,1995,1998) ytick(.95 .975 to 1.05) ylab(.95,1,1.05) yline(.95,.975,1,1.025,1.05)
translate "c:/texdocs/tfpest/fig/graphs/tfplevel-entrext-`esttype'-`ext'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2.gph" "c:/texdocs/tfpest/fig/graphs/tfplevel-entrext-`esttype'-`ext'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2.eps", translator(gph2eps) replace
erase "c:/texdocs/tfpest/fig/graphs/tfplevel-entrext-`esttype'-`ext'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2.gph"
more
graph agglntfp1 agglntfp2 year if region==9 & aggtype==2, connect(llll) saving("c:/texdocs/tfpest/fig/graphs/tfplevel-entrext-`esttype'-`ext'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2-ind14", replace) xtick(1986,1987,1988,1989,1990,1991,1992,1993,1994,1995,1996,1997,1998) xlabel(1986,1989,1992,1995,1998) ytick(.95 .975 to 1.05) ylab(.95,1,1.05) yline(.95,.975,1,1.025,1.05)
translate "c:/texdocs/tfpest/fig/graphs/tfplevel-entrext-`esttype'-`ext'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2-ind14.gph" "c:/texdocs/tfpest/fig/graphs/tfplevel-entrext-`esttype'-`ext'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2-ind14.eps", translator(gph2eps) replace
erase "c:/texdocs/tfpest/fig/graphs/tfplevel-entrext-`esttype'-`ext'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2-ind14.gph"
more


/* Figure 3.7 in WB draft */

use "tfpest/aggtfp/prodlevel`rebase'-annual-agg-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", clear
replace year=year+1900
foreach i in 1 2 { replace agglntfp`i'=1 if agglntfp`i'==0 }
keep aggtype year region agglntfp*
reshape wide agglntfp*, i(aggtype year) j(region)
foreach i in 1 2 {
    label var agglntfp`i'0 "Sao Paulo state"
    label var agglntfp`i'1 "North and North-East"
    label var agglntfp`i'3 "South and South-East (excl. SP)"
    label var agglntfp`i'9 "Brazil"
    }
graph agglntfp2* year if aggtype==1, connect(l[_]l[_]l[_]l) s(OTSd) saving("c:/texdocs/tfpest/fig/graphs/tfplevel-reg-`esttype'-`ext'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2", replace) xtick(1986,1987,1988,1989,1990,1991,1992,1993,1994,1995,1996,1997,1998) xlabel(1986,1989,1992,1995,1998) ytick(.95 .975 to 1.05) ylab(.95,1,1.05) yline(.95,.975,1,1.025,1.05)
translate "c:/texdocs/tfpest/fig/graphs/tfplevel-reg-`esttype'-`ext'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2.gph" "c:/texdocs/tfpest/fig/graphs/tfplevel-reg-`esttype'-`ext'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2.eps", translator(gph2eps) replace
erase "c:/texdocs/tfpest/fig/graphs/tfplevel-reg-`esttype'-`ext'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2.gph"
more
graph agglntfp2* year if aggtype==2, connect(l[_]l[_]l[_]l) s(OTSd) saving("c:/texdocs/tfpest/fig/graphs/tfplevel-reg-`esttype'-`ext'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2-ind14", replace) xtick(1986,1987,1988,1989,1990,1991,1992,1993,1994,1995,1996,1997,1998) xlabel(1986,1989,1992,1995,1998) ytick(.95 .975 to 1.05) ylab(.95,1,1.05) yline(.95,.975,1,1.025,1.05)
translate "c:/texdocs/tfpest/fig/graphs/tfplevel-reg-`esttype'-`ext'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2-ind14.gph" "c:/texdocs/tfpest/fig/graphs/tfplevel-reg-`esttype'-`ext'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2-ind14.eps", translator(gph2eps) replace
erase "c:/texdocs/tfpest/fig/graphs/tfplevel-reg-`esttype'-`ext'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2-ind14.gph"

}
