version 7.0

/* Choose Settings */
/*-----------------*/

foreach esttype in $esttype {
/* Choice "ols": OLS         */
/*        "fe" : Within Eff. */
/*        "op" : Olley-Pakes */
/*        "eop": Expectations-extended Olley-Pakes */

local choice 3
/* Choice 3: FGV-IPA (and general)  Deflators 86-98 */
/*        4: FGV-DI (and general)   Deflators 86-98 */
/*        9: Apply IGP-OG to all variables */
if `choice'==3 {local ext "ipa"}
if `choice'==4 {local ext "di"}
if `choice'==9 {local ext "gen"}

local fdfl 2
/* Choice 0: Foreign inputs and investments deflated with domestic deflators */
/*        1: Foreign input and investment deflators based on OECD PPI series * USD exchange rate */
/*        2: Foreign input and investment deflators based on World PPI, WPI, CPI series * USD exchange rate */
if `fdfl'==0 { local fdfl="" }

global out 2
/* Choice 1: "valadd" */
/* Choice 2: "output" */
if $out==1 {local outtype "valadd"}
if $out==2 {local outtype "output"}

global trd 0
/* Choice 3: Klette & Griliches 96 correction */
/* Choice 2: year dummies ON, trend variables OFF */
/* Choice 1: trend variables ON, time dummies OFF  */
/* Choice 0: trend variables and year dummies OFF */
if $trd==3 {local trdtype "kletgri"}
if $trd==2 {local trdtype "dyears"}
if $trd==1 {local trdtype "trend"}
if $trd==0 {local trdtype "notrend"}

global fe 2
/* Choice 2: fixed effects in OP estimation ON, AND KletGri96 inspired correction */
/* Choice 1: fixed effects in OP estimation ON  */
/* Choice 0: fixed effects in OP estimation OFF */
if $fe==2 & "`esttype'"~="op" {global fe 1}
if $fe~=0 {local fetype "fe"}
else      {local fetype "nofe"}
if $fe==2 {local feout="fecorr"}
else      {local feout="`fetype'"}

global polynl 3
/* Choice 2: Polynomial of 2nd order is used in Step 3 */
/* Choice 3: Polynomial of 3rd order is used in Step 3 */
/* Choice 4: Polynomial of 4th order is used in Step 3 */
/* Choice 5: Polynomial of 5th order is used in Step 3 */
/* Choice 6: Polynomial of 6th order is used in Step 3 */
local polynl=$polynl

global xeff 1
/* Choice 1: Approximate for X-efficiency choice by managers */
/* Choice 0: Approximate for X-efficiency choice by managers */
if $xeff {local xeff="x"}


use "tfpest/aggtfp/prodlevel1-annual-compagg-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'", clear
sort aggtype region year

replace year=year+1900

label var nmagglntfp1  "Log TFP"
label var nmagglnlp1   "Log Labor Productivity"
label var nmagglntfp2  "Log TFP: Survivors"
label var nmagglnlp2   "Log LP: Survivors"
replace nmagglntfp2=. if year==1986
replace nmagglnlp2=.  if year==1986

label var lntfppim       "Log TFP in PIM (V. Gomes 01)"
label var lntfpfiesp     "Log TFP in FIESP (V. Gomes 01)"

graph nmagglntfp1 nmagglnlp1 year if aggtype==1 & region==9, connect(lllllllll) saving("c:/texdocs/tfpest/fig/graphs/tfplevel-all-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg1", replace) xtick(1986,1987,1988,1989,1990,1991,1992,1993,1994,1995,1996,1997,1998) xlabel(1986,1989,1992,1995,1998) ytick(.95, .975 to 1.075) ylabel(.95,1,1.05)
translate "c:/texdocs/tfpest/fig/graphs/tfplevel-all-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg1.gph" "c:/texdocs/tfpest/fig/graphs/tfplevel-all-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg1.eps", translator(gph2eps) replace
erase "c:/texdocs/tfpest/fig/graphs/tfplevel-all-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg1.gph"
more

graph nmagglntfp1 nmagglntfp2 year if aggtype==1 & region==9, connect(lllllllll) saving("c:/texdocs/tfpest/fig/graphs/tfplevel-stayers-2-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg1", replace) xtick(1986,1987,1988,1989,1990,1991,1992,1993,1994,1995,1996,1997,1998) xlabel(1986,1989,1992,1995,1998) ytick(.95, .975 to 1.05) ylabel(.95,1,1.05)
translate "c:/texdocs/tfpest/fig/graphs/tfplevel-stayers-2-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg1.gph" "c:/texdocs/tfpest/fig/graphs/tfplevel-stayers-2-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg1.eps", translator(gph2eps) replace
erase "c:/texdocs/tfpest/fig/graphs/tfplevel-stayers-2-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg1.gph"
more

graph nmagglntfp1 lntfppim year if aggtype==1 & region==9, connect(lllllllll) saving("c:/texdocs/tfpest/fig/graphs/tfplevel-pia-pim-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg1", replace) xtick(1986,1987,1988,1989,1990,1991,1992,1993,1994,1995,1996,1997,1998) xlabel(1986,1989,1992,1995,1998) ytick(.9, .925 to 1.05) ylab(.9,.95,1,1.05) rlab(.85 .9 to 1.25)
translate "c:/texdocs/tfpest/fig/graphs/tfplevel-pia-pim-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg1.gph" "c:/texdocs/tfpest/fig/graphs/tfplevel-pia-pim-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg1.eps", translator(gph2eps) replace
erase "c:/texdocs/tfpest/fig/graphs/tfplevel-pia-pim-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg1.gph"
more

label var nmagglntfp1  "Log TFP in PIA - SP state"
graph nmagglntfp1 lntfpfiesp year if aggtype==1 & region==3, connect(lllllllll) saving("c:/texdocs/tfpest/fig/graphs/tfplevel-pia-sp-fiesp-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg1", replace) xtick(1986,1987,1988,1989,1990,1991,1992,1993,1994,1995,1996,1997,1998) xlabel(1986,1989,1992,1995,1998) ytick(.9, .925 to 1.05) ylab(.9,.95,1,1.05) rlab(.85 .9 to 1.15)
translate "c:/texdocs/tfpest/fig/graphs/tfplevel-pia-sp-fiesp-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg1.gph" "c:/texdocs/tfpest/fig/graphs/tfplevel-pia-sp-fiesp-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg1.eps", translator(gph2eps) replace
erase "c:/texdocs/tfpest/fig/graphs/tfplevel-pia-sp-fiesp-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg1.gph"
label var nmagglntfp1  "Log TFP in PIA"
more

graph nmagglntfp1 nmagglntfp2 year if aggtype==2 & region==9, connect(lllllllll) saving("c:/texdocs/tfpest/fig/graphs/tfplevel-stayers-2-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2", replace) xtick(1986,1987,1988,1989,1990,1991,1992,1993,1994,1995,1996,1997,1998) xlabel(1986,1989,1992,1995,1998) ytick(.975,1,1.025,1.05) ylabel(1,1.05)
translate "c:/texdocs/tfpest/fig/graphs/tfplevel-stayers-2-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2.gph" "c:/texdocs/tfpest/fig/graphs/tfplevel-stayers-2-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2.eps", translator(gph2eps) replace
erase "c:/texdocs/tfpest/fig/graphs/tfplevel-stayers-2-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2.gph"
more

graph nmagglntfp1 lntfppim year if aggtype==2 & region==9, connect(lllllllll) saving("c:/texdocs/tfpest/fig/graphs/tfplevel-pia-pim-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2", replace) xtick(1986,1987,1988,1989,1990,1991,1992,1993,1994,1995,1996,1997,1998) xlabel(1986,1989,1992,1995,1998) ytick(.95 .975 to 1.05) ylab(.95,1,1.05) rlab(.85 .9 to 1.25)
translate "c:/texdocs/tfpest/fig/graphs/tfplevel-pia-pim-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2.gph" "c:/texdocs/tfpest/fig/graphs/tfplevel-pia-pim-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2.eps", translator(gph2eps) replace
erase "c:/texdocs/tfpest/fig/graphs/tfplevel-pia-pim-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2.gph"
more

label var nmagglntfp1  "Log TFP in PIA - SP state"
graph nmagglntfp1 lntfpfiesp year if aggtype==2 & region==3, connect(lllllllll) saving("c:/texdocs/tfpest/fig/graphs/tfplevel-pia-sp-fiesp-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2", replace) xtick(1986,1987,1988,1989,1990,1991,1992,1993,1994,1995,1996,1997,1998) xlabel(1986,1989,1992,1995,1998) ytick(.95 .975 to 1.05) ylab(.95,1,1.05) rlab(.85 .9 to 1.15)
translate "c:/texdocs/tfpest/fig/graphs/tfplevel-pia-sp-fiesp-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2.gph" "c:/texdocs/tfpest/fig/graphs/tfplevel-pia-sp-fiesp-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2.eps", translator(gph2eps) replace
erase "c:/texdocs/tfpest/fig/graphs/tfplevel-pia-sp-fiesp-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg2.gph"
label var nmagglntfp1  "Log TFP in PIA"
more

label var lntfpellgom "Log TFP Brazil (Bugarin&al. 02)"
graph nmagglntfp1 nmagglnlp1 lntfpellgom year if aggtype==1 & region==9, connect(lll[_#_]) saving("c:/texdocs/tfpest/fig/graphs/tfplevel-pia-ellgom-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg1", replace) xtick(1986,1987,1988,1989,1990,1991,1992,1993,1994,1995,1996,1997,1998) xlabel(1986,1989,1992,1995,1998) ytick(.95, .975 to 1.075) ylabel(.95,1,1.05)
translate "c:/texdocs/tfpest/fig/graphs/tfplevel-pia-ellgom-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg1.gph" "c:/texdocs/tfpest/fig/graphs/tfplevel-pia-ellgom-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg1.eps", translator(gph2eps) replace
erase "c:/texdocs/tfpest/fig/graphs/tfplevel-pia-ellgom-`esttype'-`ext'`fdfl'-`outtype'-`trdtype'-`fetype'-`polynl'`xeff'-agg1.gph"
more

}
